Function UICellAccessoryPositionAfterAccessoryOfClass

pub unsafe extern "C-unwind" fn UICellAccessoryPositionAfterAccessoryOfClass(
    accessory_class: &AnyClass,
) -> UICellAccessoryPosition
Available on crate features UICellAccessory and block2 only.
Positions the accessory after the accessory matching the class specified, or at the end if not found.