Function UICellAccessoryPositionBeforeAccessoryOfClass

pub unsafe extern "C-unwind" fn UICellAccessoryPositionBeforeAccessoryOfClass(
    accessory_class: &AnyClass,
) -> UICellAccessoryPosition
Available on crate features UICellAccessory and block2 only.
Positions the accessory before the accessory matching the class specified, or at the beginning if not found.