Function UIImageHEICRepresentation

pub unsafe extern "C-unwind" fn UIImageHEICRepresentation(
    image: &UIImage,
) -> Option<Retained<NSData>>
Available on crate feature UIImage only.
Returns HEIC data representing the image, or nil if such a representation could not be generated. HEIC is recommended for efficiently storing all kinds of images, including those with high dynamic range content.