Struct objc2_ui_kit::UIAccelerometer
source · #[repr(C)]pub struct UIAccelerometer { /* private fields */ }👎Deprecated: UIAccelerometer has been replaced by the CoreMotion framework
Available on crate feature
UIAccelerometer only.Implementations
sourceimpl UIAccelerometer
impl UIAccelerometer
👎Deprecated: UIAccelerometer has been replaced by the CoreMotion framework
pub unsafe fn updateInterval(&self) -> NSTimeInterval
👎Deprecated: UIAccelerometer has been replaced by the CoreMotion framework
pub unsafe fn setUpdateInterval(&self, update_interval: NSTimeInterval)
👎Deprecated: UIAccelerometer has been replaced by the CoreMotion framework
pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn UIAccelerometerDelegate>>>
👎Deprecated: UIAccelerometer has been replaced by the CoreMotion framework
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn UIAccelerometerDelegate>> )
👎Deprecated: UIAccelerometer has been replaced by the CoreMotion framework
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.