Struct objc2_ui_kit::UIActivityItemProvider
source · #[repr(C)]pub struct UIActivityItemProvider { /* private fields */ }Available on crate feature
UIActivityItemProvider only.Implementations
sourceimpl UIActivityItemProvider
impl UIActivityItemProvider
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithPlaceholderItem( this: Allocated<Self>, placeholder_item: &AnyObject ) -> Retained<Self>
pub unsafe fn placeholderItem(&self) -> Option<Retained<AnyObject>>
pub unsafe fn activityType(&self) -> Option<Retained<UIActivityType>>
Available on crate feature
UIActivity only.pub unsafe fn item(&self) -> Retained<AnyObject>
Methods from Deref<Target = NSOperation>
pub unsafe fn start(&self)
pub unsafe fn main(&self)
pub unsafe fn isCancelled(&self) -> bool
pub unsafe fn cancel(&self)
pub unsafe fn isExecuting(&self) -> bool
pub unsafe fn isFinished(&self) -> bool
pub unsafe fn isConcurrent(&self) -> bool
pub unsafe fn isAsynchronous(&self) -> bool
pub unsafe fn isReady(&self) -> bool
pub unsafe fn addDependency(&self, op: &NSOperation)
pub unsafe fn removeDependency(&self, op: &NSOperation)
pub unsafe fn dependencies(&self) -> Retained<NSArray<NSOperation>>
Available on crate feature
NSArray only.pub unsafe fn queuePriority(&self) -> NSOperationQueuePriority
pub unsafe fn setQueuePriority(&self, queue_priority: NSOperationQueuePriority)
pub unsafe fn completionBlock(&self) -> *mut Block<dyn Fn()>
Available on crate feature
block2 only.pub unsafe fn setCompletionBlock( &self, completion_block: Option<&Block<dyn Fn()>> )
Available on crate feature
block2 only.pub unsafe fn waitUntilFinished(&self)
pub unsafe fn threadPriority(&self) -> f64
👎Deprecated: Not supported
pub unsafe fn setThreadPriority(&self, thread_priority: f64)
👎Deprecated: Not supported
pub unsafe fn qualityOfService(&self) -> NSQualityOfService
Available on crate feature
NSObjCRuntime only.pub unsafe fn setQualityOfService(&self, quality_of_service: NSQualityOfService)
Available on crate feature
NSObjCRuntime only.pub unsafe fn name(&self) -> Option<Retained<NSString>>
Available on crate feature
NSString only.pub unsafe fn setName(&self, name: Option<&NSString>)
Available on crate feature
NSString only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.