Struct objc2_ui_kit::UIApplication

source ·
#[repr(C)]
pub struct UIApplication { /* private fields */ }
Available on crate features UIApplication and UIResponder only.

Implementations

source

impl UIApplication

source

pub fn sharedApplication(mtm: MainThreadMarker) -> Retained<UIApplication>

source

pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn UIApplicationDelegate>>>

source

pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn UIApplicationDelegate>> )

source

pub unsafe fn beginIgnoringInteractionEvents(&self)

👎Deprecated: Use UIView’s userInteractionEnabled property instead
source

pub unsafe fn endIgnoringInteractionEvents(&self)

👎Deprecated: Use UIView’s userInteractionEnabled property instead
source

pub unsafe fn isIgnoringInteractionEvents(&self) -> bool

👎Deprecated: Use UIView’s userInteractionEnabled property instead
source

pub unsafe fn isIdleTimerDisabled(&self) -> bool

source

pub unsafe fn setIdleTimerDisabled(&self, idle_timer_disabled: bool)

source

pub unsafe fn openURL(&self, url: &NSURL) -> bool

👎Deprecated
source

pub unsafe fn canOpenURL(&self, url: &NSURL) -> bool

source

pub unsafe fn openURL_options_completionHandler( &self, url: &NSURL, options: &NSDictionary<UIApplicationOpenExternalURLOptionsKey, AnyObject>, completion: Option<&Block<dyn Fn(Bool)>> )

Available on crate feature block2 only.
source

pub unsafe fn sendEvent(&self, event: &UIEvent)

Available on crate feature UIEvent only.
source

pub unsafe fn keyWindow(&self) -> Option<Retained<UIWindow>>

👎Deprecated: Should not be used for applications that support multiple scenes as it returns a key window across all connected scenes
Available on crate features UIView and UIWindow only.
source

pub fn windows(&self) -> Retained<NSArray<UIWindow>>

👎Deprecated: Use UIWindowScene.windows on a relevant window scene instead
Available on crate features UIView and UIWindow only.
source

pub unsafe fn sendAction_to_from_forEvent( &self, action: Sel, target: Option<&AnyObject>, sender: Option<&AnyObject>, event: Option<&UIEvent> ) -> bool

Available on crate feature UIEvent only.
source

pub unsafe fn isNetworkActivityIndicatorVisible(&self) -> bool

👎Deprecated: Provide a custom network activity UI in your app if desired.
source

pub unsafe fn setNetworkActivityIndicatorVisible( &self, network_activity_indicator_visible: bool )

👎Deprecated: Provide a custom network activity UI in your app if desired.
source

pub unsafe fn supportedInterfaceOrientationsForWindow( &self, window: Option<&UIWindow> ) -> UIInterfaceOrientationMask

Available on crate features UIOrientation and UIView and UIWindow only.
source

pub unsafe fn statusBarOrientationAnimationDuration(&self) -> NSTimeInterval

👎Deprecated: Use viewWillTransitionToSize:withTransitionCoordinator: instead.
source

pub fn statusBarFrame(&self) -> CGRect

👎Deprecated: Use the statusBarManager property of the window scene instead.
source

pub unsafe fn applicationIconBadgeNumber(&self) -> NSInteger

👎Deprecated: Use -[UNUserNotificationCenter setBadgeCount:withCompletionHandler:] instead.
source

pub unsafe fn setApplicationIconBadgeNumber( &self, application_icon_badge_number: NSInteger )

👎Deprecated: Use -[UNUserNotificationCenter setBadgeCount:withCompletionHandler:] instead.
source

pub unsafe fn applicationSupportsShakeToEdit(&self) -> bool

source

pub unsafe fn setApplicationSupportsShakeToEdit( &self, application_supports_shake_to_edit: bool )

source

pub unsafe fn applicationState(&self) -> UIApplicationState

source

pub unsafe fn backgroundTimeRemaining(&self) -> NSTimeInterval

source

pub unsafe fn beginBackgroundTaskWithExpirationHandler( &self, handler: Option<&Block<dyn Fn()>> ) -> UIBackgroundTaskIdentifier

Available on crate feature block2 only.
source

pub unsafe fn beginBackgroundTaskWithName_expirationHandler( &self, task_name: Option<&NSString>, handler: Option<&Block<dyn Fn()>> ) -> UIBackgroundTaskIdentifier

Available on crate feature block2 only.
source

pub unsafe fn endBackgroundTask(&self, identifier: UIBackgroundTaskIdentifier)

source

pub unsafe fn setMinimumBackgroundFetchInterval( &self, minimum_background_fetch_interval: NSTimeInterval )

👎Deprecated: Use a BGAppRefreshTask in the BackgroundTasks framework instead
source

pub unsafe fn backgroundRefreshStatus(&self) -> UIBackgroundRefreshStatus

source

pub unsafe fn isProtectedDataAvailable(&self) -> bool

source

pub unsafe fn userInterfaceLayoutDirection( &self ) -> UIUserInterfaceLayoutDirection

Available on crate feature UIInterface only.
source

pub unsafe fn preferredContentSizeCategory( &self ) -> Retained<UIContentSizeCategory>

Available on crate feature UIContentSizeCategory only.
source

pub unsafe fn connectedScenes(&self) -> Retained<NSSet<UIScene>>

Available on crate feature UIScene only.
source

pub unsafe fn openSessions(&self) -> Retained<NSSet<UISceneSession>>

Available on crate feature UISceneSession only.
source

pub unsafe fn supportsMultipleScenes(&self) -> bool

source

pub unsafe fn activateSceneSessionForRequest_errorHandler( &self, request: &UISceneSessionActivationRequest, error_handler: Option<&Block<dyn Fn(NonNull<NSError>)>> )

Available on crate features UISceneSessionActivationRequest and block2 only.
source

pub unsafe fn requestSceneSessionActivation_userActivity_options_errorHandler( &self, scene_session: Option<&UISceneSession>, user_activity: Option<&NSUserActivity>, options: Option<&UISceneActivationRequestOptions>, error_handler: Option<&Block<dyn Fn(NonNull<NSError>)>> )

👎Deprecated: Please use activateSceneSessionForRequest:errorHandler:
Available on crate features UISceneOptions and UISceneSession and block2 only.
source

pub unsafe fn requestSceneSessionDestruction_options_errorHandler( &self, scene_session: &UISceneSession, options: Option<&UISceneDestructionRequestOptions>, error_handler: Option<&Block<dyn Fn(NonNull<NSError>)>> )

Available on crate features UISceneOptions and UISceneSession and block2 only.
source

pub unsafe fn requestSceneSessionRefresh(&self, scene_session: &UISceneSession)

Available on crate feature UISceneSession only.
source

impl UIApplication

Methods declared on superclass NSObject

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

source

impl UIApplication

UIRemoteNotifications

source

pub unsafe fn registerForRemoteNotifications(&self)

source

pub unsafe fn unregisterForRemoteNotifications(&self)

source

pub unsafe fn isRegisteredForRemoteNotifications(&self) -> bool

source

pub unsafe fn registerForRemoteNotificationTypes( &self, types: UIRemoteNotificationType )

👎Deprecated: Use -[UIApplication registerForRemoteNotifications] and UserNotifications Framework’s -[UNUserNotificationCenter requestAuthorizationWithOptions:completionHandler:]
source

pub unsafe fn enabledRemoteNotificationTypes(&self) -> UIRemoteNotificationType

👎Deprecated: Use -[UIApplication isRegisteredForRemoteNotifications] and UserNotifications Framework’s -[UNUserNotificationCenter getNotificationSettingsWithCompletionHandler:] to retrieve user-enabled remote notification and user notification settings
source

impl UIApplication

UILocalNotifications

source

pub unsafe fn presentLocalNotificationNow( &self, notification: &UILocalNotification )

👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter addNotificationRequest:withCompletionHandler:]
Available on crate feature UILocalNotification only.
source

pub unsafe fn scheduleLocalNotification( &self, notification: &UILocalNotification )

👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter addNotificationRequest:withCompletionHandler:]
Available on crate feature UILocalNotification only.
source

pub unsafe fn cancelLocalNotification(&self, notification: &UILocalNotification)

👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter removePendingNotificationRequestsWithIdentifiers:]
Available on crate feature UILocalNotification only.
source

pub unsafe fn cancelAllLocalNotifications(&self)

👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter removeAllPendingNotificationRequests]
source

pub unsafe fn scheduledLocalNotifications( &self ) -> Option<Retained<NSArray<UILocalNotification>>>

👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter getPendingNotificationRequestsWithCompletionHandler:]
Available on crate feature UILocalNotification only.
source

pub unsafe fn setScheduledLocalNotifications( &self, scheduled_local_notifications: Option<&NSArray<UILocalNotification>> )

👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter getPendingNotificationRequestsWithCompletionHandler:]
Available on crate feature UILocalNotification only.
source

impl UIApplication

UIUserNotificationSettings

source

pub unsafe fn registerUserNotificationSettings( &self, notification_settings: &UIUserNotificationSettings )

👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter requestAuthorizationWithOptions:completionHandler:] and -[UNUserNotificationCenter setNotificationCategories:]
Available on crate feature UIUserNotificationSettings only.
source

pub unsafe fn currentUserNotificationSettings( &self ) -> Option<Retained<UIUserNotificationSettings>>

👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter getNotificationSettingsWithCompletionHandler:] and -[UNUserNotificationCenter getNotificationCategoriesWithCompletionHandler:]
Available on crate feature UIUserNotificationSettings only.
source

impl UIApplication

UIRemoteControlEvents

source

impl UIApplication

UINewsstand

source

pub unsafe fn setNewsstandIconImage(&self, image: Option<&UIImage>)

👎Deprecated: Newsstand apps now behave like normal apps on SpringBoard
Available on crate feature UIImage only.
source

impl UIApplication

UIShortcutItems

source

pub unsafe fn shortcutItems( &self ) -> Option<Retained<NSArray<UIApplicationShortcutItem>>>

Available on crate feature UIApplicationShortcutItem only.
source

pub unsafe fn setShortcutItems( &self, shortcut_items: Option<&NSArray<UIApplicationShortcutItem>> )

Available on crate feature UIApplicationShortcutItem only.
source

impl UIApplication

UIAlternateApplicationIcons

source

pub unsafe fn supportsAlternateIcons(&self) -> bool

source

pub unsafe fn setAlternateIconName_completionHandler( &self, alternate_icon_name: Option<&NSString>, completion_handler: Option<&Block<dyn Fn(*mut NSError)>> )

Available on crate feature block2 only.
source

pub unsafe fn alternateIconName(&self) -> Option<Retained<NSString>>

source

impl UIApplication

UIStateRestoration

source

pub unsafe fn extendStateRestoration(&self)

source

pub unsafe fn completeStateRestoration(&self)

source

pub unsafe fn ignoreSnapshotOnNextApplicationLaunch(&self)

source

pub unsafe fn registerObjectForStateRestoration_restorationIdentifier( object: &ProtocolObject<dyn UIStateRestoring>, restoration_identifier: &NSString )

Available on crate feature UIStateRestoration only.
source

impl UIApplication

UIApplicationDeprecated

source

pub unsafe fn isProximitySensingEnabled(&self) -> bool

👎Deprecated
source

pub unsafe fn setProximitySensingEnabled(&self, proximity_sensing_enabled: bool)

👎Deprecated
source

pub unsafe fn setStatusBarHidden_animated(&self, hidden: bool, animated: bool)

👎Deprecated: Use -[UIViewController prefersStatusBarHidden]
source

pub unsafe fn setStatusBarOrientation( &self, status_bar_orientation: UIInterfaceOrientation )

👎Deprecated: Explicit setting of the status bar orientation is more limited in iOS 6.0 and later
Available on crate feature UIOrientation only.
source

pub unsafe fn setStatusBarOrientation_animated( &self, interface_orientation: UIInterfaceOrientation, animated: bool )

👎Deprecated: Explicit setting of the status bar orientation is more limited in iOS 6.0 and later
Available on crate feature UIOrientation only.
source

pub unsafe fn setStatusBarStyle(&self, status_bar_style: UIStatusBarStyle)

👎Deprecated: Use -[UIViewController preferredStatusBarStyle]
source

pub unsafe fn setStatusBarStyle_animated( &self, status_bar_style: UIStatusBarStyle, animated: bool )

👎Deprecated: Use -[UIViewController preferredStatusBarStyle]
source

pub unsafe fn setStatusBarHidden(&self, status_bar_hidden: bool)

👎Deprecated: Use -[UIViewController prefersStatusBarHidden]
source

pub unsafe fn setStatusBarHidden_withAnimation( &self, hidden: bool, animation: UIStatusBarAnimation )

👎Deprecated: Use -[UIViewController prefersStatusBarHidden]
source

pub unsafe fn setKeepAliveTimeout_handler( &self, timeout: NSTimeInterval, keep_alive_handler: Option<&Block<dyn Fn()>> ) -> bool

👎Deprecated: Please use PushKit for VoIP applications instead of calling this method
Available on crate feature block2 only.
source

pub unsafe fn clearKeepAliveTimeout(&self)

👎Deprecated: Please use PushKit for VoIP applications instead of calling this method

Methods from Deref<Target = UIResponder>

source

pub unsafe fn nextResponder(&self) -> Option<Retained<UIResponder>>

source

pub unsafe fn canBecomeFirstResponder(&self) -> bool

source

pub unsafe fn becomeFirstResponder(&self) -> bool

source

pub unsafe fn canResignFirstResponder(&self) -> bool

source

pub unsafe fn resignFirstResponder(&self) -> bool

source

pub unsafe fn isFirstResponder(&self) -> bool

source

pub unsafe fn touchesBegan_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )

Available on crate features UIEvent and UITouch only.
source

pub unsafe fn touchesMoved_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )

Available on crate features UIEvent and UITouch only.
source

pub unsafe fn touchesEnded_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )

Available on crate features UIEvent and UITouch only.
source

pub unsafe fn touchesCancelled_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )

Available on crate features UIEvent and UITouch only.
source

pub unsafe fn touchesEstimatedPropertiesUpdated(&self, touches: &NSSet<UITouch>)

Available on crate feature UITouch only.
source

pub unsafe fn pressesBegan_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )

Available on crate features UIEvent and UIPress and UIPressesEvent only.
source

pub unsafe fn pressesChanged_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )

Available on crate features UIEvent and UIPress and UIPressesEvent only.
source

pub unsafe fn pressesEnded_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )

Available on crate features UIEvent and UIPress and UIPressesEvent only.
source

pub unsafe fn pressesCancelled_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )

Available on crate features UIEvent and UIPress and UIPressesEvent only.
source

pub unsafe fn motionBegan_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )

Available on crate feature UIEvent only.
source

pub unsafe fn motionEnded_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )

Available on crate feature UIEvent only.
source

pub unsafe fn motionCancelled_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )

Available on crate feature UIEvent only.
source

pub unsafe fn remoteControlReceivedWithEvent(&self, event: Option<&UIEvent>)

Available on crate feature UIEvent only.
source

pub unsafe fn canPerformAction_withSender( &self, action: Sel, sender: Option<&AnyObject> ) -> bool

source

pub unsafe fn targetForAction_withSender( &self, action: Sel, sender: Option<&AnyObject> ) -> Option<Retained<AnyObject>>

source

pub unsafe fn buildMenuWithBuilder( &self, builder: &ProtocolObject<dyn UIMenuBuilder> )

Available on crate feature UIMenuBuilder only.
source

pub unsafe fn validateCommand(&self, command: &UICommand)

Available on crate features UICommand and UIMenuElement only.
source

pub unsafe fn undoManager(&self) -> Option<Retained<NSUndoManager>>

source

pub unsafe fn editingInteractionConfiguration( &self ) -> UIEditingInteractionConfiguration

source

pub unsafe fn keyCommands(&self) -> Option<Retained<NSArray<UIKeyCommand>>>

Available on crate features UICommand and UIKeyCommand and UIMenuElement only.
source

pub unsafe fn inputView(&self) -> Option<Retained<UIView>>

Available on crate feature UIView only.
source

pub unsafe fn inputAccessoryView(&self) -> Option<Retained<UIView>>

Available on crate feature UIView only.
source

pub unsafe fn inputAssistantItem(&self) -> Retained<UITextInputAssistantItem>

Available on crate feature UITextInput only.
source

pub unsafe fn inputViewController( &self ) -> Option<Retained<UIInputViewController>>

Available on crate features UIInputViewController and UIViewController only.
source

pub unsafe fn inputAccessoryViewController( &self ) -> Option<Retained<UIInputViewController>>

Available on crate features UIInputViewController and UIViewController only.
source

pub unsafe fn textInputMode(&self) -> Option<Retained<UITextInputMode>>

Available on crate feature UITextInput only.
source

pub unsafe fn textInputContextIdentifier(&self) -> Option<Retained<NSString>>

source

pub unsafe fn reloadInputViews(&self)

source

pub unsafe fn userActivity(&self) -> Option<Retained<NSUserActivity>>

source

pub unsafe fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)

source

pub unsafe fn updateUserActivityState(&self, activity: &NSUserActivity)

source

pub unsafe fn restoreUserActivityState(&self, activity: &NSUserActivity)

source

pub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)

source

pub unsafe fn activityItemsConfiguration( &self ) -> Option<Retained<ProtocolObject<dyn UIActivityItemsConfigurationReading>>>

Available on crate features UIResponder_UIActivityItemsConfiguration and UIActivityItemsConfigurationReading only.
source

pub unsafe fn setActivityItemsConfiguration( &self, activity_items_configuration: Option<&ProtocolObject<dyn UIActivityItemsConfigurationReading>> )

Available on crate features UIResponder_UIActivityItemsConfiguration and UIActivityItemsConfigurationReading only.

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Available on crate feature UIIndirectScribbleInteraction only.

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
Available on crate feature UIIndirectScribbleInteraction only.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
Available on crate feature UIIndirectScribbleInteraction only.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.