Struct objc2_ui_kit::UIAttachmentBehavior
source · #[repr(C)]pub struct UIAttachmentBehavior { /* private fields */ }Available on crate features
UIAttachmentBehavior and UIDynamicBehavior only.Implementations
sourceimpl UIAttachmentBehavior
impl UIAttachmentBehavior
pub unsafe fn initWithItem_attachedToAnchor( this: Allocated<Self>, item: &ProtocolObject<dyn UIDynamicItem>, point: CGPoint ) -> Retained<Self>
pub unsafe fn initWithItem_offsetFromCenter_attachedToAnchor( this: Allocated<Self>, item: &ProtocolObject<dyn UIDynamicItem>, offset: UIOffset, point: CGPoint ) -> Retained<Self>
Available on crate feature
UIGeometry only.pub unsafe fn initWithItem_attachedToItem( this: Allocated<Self>, item1: &ProtocolObject<dyn UIDynamicItem>, item2: &ProtocolObject<dyn UIDynamicItem> ) -> Retained<Self>
pub unsafe fn initWithItem_offsetFromCenter_attachedToItem_offsetFromCenter( this: Allocated<Self>, item1: &ProtocolObject<dyn UIDynamicItem>, offset1: UIOffset, item2: &ProtocolObject<dyn UIDynamicItem>, offset2: UIOffset ) -> Retained<Self>
Available on crate feature
UIGeometry only.pub unsafe fn slidingAttachmentWithItem_attachedToItem_attachmentAnchor_axisOfTranslation( item1: &ProtocolObject<dyn UIDynamicItem>, item2: &ProtocolObject<dyn UIDynamicItem>, point: CGPoint, axis: CGVector ) -> Retained<Self>
pub unsafe fn slidingAttachmentWithItem_attachmentAnchor_axisOfTranslation( item: &ProtocolObject<dyn UIDynamicItem>, point: CGPoint, axis: CGVector ) -> Retained<Self>
pub unsafe fn limitAttachmentWithItem_offsetFromCenter_attachedToItem_offsetFromCenter( item1: &ProtocolObject<dyn UIDynamicItem>, offset1: UIOffset, item2: &ProtocolObject<dyn UIDynamicItem>, offset2: UIOffset ) -> Retained<Self>
Available on crate feature
UIGeometry only.pub unsafe fn fixedAttachmentWithItem_attachedToItem_attachmentAnchor( item1: &ProtocolObject<dyn UIDynamicItem>, item2: &ProtocolObject<dyn UIDynamicItem>, point: CGPoint ) -> Retained<Self>
pub unsafe fn pinAttachmentWithItem_attachedToItem_attachmentAnchor( item1: &ProtocolObject<dyn UIDynamicItem>, item2: &ProtocolObject<dyn UIDynamicItem>, point: CGPoint ) -> Retained<Self>
pub unsafe fn items( &self ) -> Retained<NSArray<ProtocolObject<dyn UIDynamicItem>>>
pub unsafe fn attachedBehaviorType(&self) -> UIAttachmentBehaviorType
pub unsafe fn anchorPoint(&self) -> CGPoint
pub unsafe fn setAnchorPoint(&self, anchor_point: CGPoint)
pub unsafe fn length(&self) -> CGFloat
pub unsafe fn setLength(&self, length: CGFloat)
pub unsafe fn damping(&self) -> CGFloat
pub unsafe fn setDamping(&self, damping: CGFloat)
pub unsafe fn frequency(&self) -> CGFloat
pub unsafe fn setFrequency(&self, frequency: CGFloat)
pub unsafe fn frictionTorque(&self) -> CGFloat
pub unsafe fn setFrictionTorque(&self, friction_torque: CGFloat)
pub unsafe fn attachmentRange(&self) -> UIFloatRange
pub unsafe fn setAttachmentRange(&self, attachment_range: UIFloatRange)
Methods from Deref<Target = UIDynamicBehavior>
pub unsafe fn addChildBehavior(&self, behavior: &UIDynamicBehavior)
pub unsafe fn removeChildBehavior(&self, behavior: &UIDynamicBehavior)
pub unsafe fn childBehaviors(&self) -> Retained<NSArray<UIDynamicBehavior>>
pub unsafe fn action(&self) -> *mut Block<dyn Fn()>
Available on crate feature
block2 only.pub unsafe fn setAction(&self, action: Option<&Block<dyn Fn()>>)
Available on crate feature
block2 only.pub unsafe fn willMoveToAnimator( &self, dynamic_animator: Option<&UIDynamicAnimator> )
Available on crate feature
UIDynamicAnimator only.pub unsafe fn dynamicAnimator(&self) -> Option<Retained<UIDynamicAnimator>>
Available on crate feature
UIDynamicAnimator only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.