#[repr(transparent)]pub struct UIBarButtonItemStyle(pub NSInteger);UIBarButtonItem only.Expand description
Tuple Fields
0: NSIntegerImplementations
Sourceimpl UIBarButtonItemStyle
impl UIBarButtonItemStyle
pub const Plain: Self
Sourcepub const Prominent: Self
pub const Prominent: Self
A button item style for a prominent button.
For example, use this for a button that completes or finalizes some task. Buttons with this style will not be visually grouped with other items in a navigation bar or toolbar, and will also have other styling changes appropriate to their context to indicate their prominence.
Sourcepub const Bordered: Self
👎Deprecated
pub const Bordered: Self
A button item style for a prominent button.
For example, use this for a button that completes or finalizes some task. Buttons with this style will not be visually grouped with other items in a navigation bar or toolbar, and will also have other styling changes appropriate to their context to indicate their prominence.
Sourcepub const Done: Self
👎Deprecated
pub const Done: Self
A button item style for a prominent button.
For example, use this for a button that completes or finalizes some task. Buttons with this style will not be visually grouped with other items in a navigation bar or toolbar, and will also have other styling changes appropriate to their context to indicate their prominence.