Struct objc2_ui_kit::UICellAccessoryCustomView
source · #[repr(C)]pub struct UICellAccessoryCustomView { /* private fields */ }Available on crate feature
UICellAccessory only.Implementations
sourceimpl UICellAccessoryCustomView
impl UICellAccessoryCustomView
pub unsafe fn initWithCustomView_placement( this: Allocated<Self>, custom_view: &UIView, placement: UICellAccessoryPlacement ) -> Retained<Self>
Available on crate features
UIResponder and UIView only.pub unsafe fn customView(&self) -> Retained<UIView>
Available on crate features
UIResponder and UIView only.pub unsafe fn placement(&self) -> UICellAccessoryPlacement
pub unsafe fn maintainsFixedSize(&self) -> bool
pub unsafe fn setMaintainsFixedSize(&self, maintains_fixed_size: bool)
pub unsafe fn position(&self) -> UICellAccessoryPosition
Available on crate feature
block2 only.pub unsafe fn setPosition(&self, position: UICellAccessoryPosition)
Available on crate feature
block2 only.pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder ) -> Option<Retained<Self>>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = UICellAccessory>
pub unsafe fn displayedState(&self) -> UICellAccessoryDisplayedState
pub unsafe fn setDisplayedState( &self, displayed_state: UICellAccessoryDisplayedState )
pub unsafe fn isHidden(&self) -> bool
pub unsafe fn setHidden(&self, hidden: bool)
pub unsafe fn reservedLayoutWidth(&self) -> CGFloat
pub unsafe fn setReservedLayoutWidth(&self, reserved_layout_width: CGFloat)
pub unsafe fn tintColor(&self) -> Option<Retained<UIColor>>
Available on crate feature
UIColor only.pub unsafe fn setTintColor(&self, tint_color: Option<&UIColor>)
Available on crate feature
UIColor only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.