#[repr(C)]pub struct UICollectionLayoutListConfiguration { /* private fields */ }Available on crate feature
UICollectionLayoutList only.Implementations
sourceimpl UICollectionLayoutListConfiguration
impl UICollectionLayoutListConfiguration
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithAppearance( this: Allocated<Self>, appearance: UICollectionLayoutListAppearance ) -> Retained<Self>
pub unsafe fn appearance(&self) -> UICollectionLayoutListAppearance
pub unsafe fn showsSeparators(&self) -> bool
pub unsafe fn setShowsSeparators(&self, shows_separators: bool)
pub unsafe fn separatorConfiguration( &self ) -> Retained<UIListSeparatorConfiguration>
Available on crate feature
UIListSeparatorConfiguration only.pub unsafe fn setSeparatorConfiguration( &self, separator_configuration: &UIListSeparatorConfiguration )
Available on crate feature
UIListSeparatorConfiguration only.pub unsafe fn itemSeparatorHandler( &self ) -> UICollectionLayoutListItemSeparatorHandler
Available on crate features
UIListSeparatorConfiguration and block2 only.pub unsafe fn setItemSeparatorHandler( &self, item_separator_handler: UICollectionLayoutListItemSeparatorHandler )
Available on crate features
UIListSeparatorConfiguration and block2 only.pub unsafe fn backgroundColor(&self) -> Option<Retained<UIColor>>
Available on crate feature
UIColor only.pub unsafe fn setBackgroundColor(&self, background_color: Option<&UIColor>)
Available on crate feature
UIColor only.pub unsafe fn leadingSwipeActionsConfigurationProvider( &self ) -> UICollectionLayoutListSwipeActionsConfigurationProvider
Available on crate features
UISwipeActionsConfiguration and block2 only.pub unsafe fn setLeadingSwipeActionsConfigurationProvider( &self, leading_swipe_actions_configuration_provider: UICollectionLayoutListSwipeActionsConfigurationProvider )
Available on crate features
UISwipeActionsConfiguration and block2 only.pub unsafe fn trailingSwipeActionsConfigurationProvider( &self ) -> UICollectionLayoutListSwipeActionsConfigurationProvider
Available on crate features
UISwipeActionsConfiguration and block2 only.pub unsafe fn setTrailingSwipeActionsConfigurationProvider( &self, trailing_swipe_actions_configuration_provider: UICollectionLayoutListSwipeActionsConfigurationProvider )
Available on crate features
UISwipeActionsConfiguration and block2 only.pub unsafe fn headerMode(&self) -> UICollectionLayoutListHeaderMode
pub unsafe fn setHeaderMode( &self, header_mode: UICollectionLayoutListHeaderMode )
pub unsafe fn headerTopPadding(&self) -> CGFloat
pub unsafe fn setHeaderTopPadding(&self, header_top_padding: CGFloat)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.