#[repr(C)]pub struct UICollectionViewFocusUpdateContext { /* private fields */ }Available on crate features
UICollectionView and UIFocus only.Implementations
sourceimpl UICollectionViewFocusUpdateContext
impl UICollectionViewFocusUpdateContext
pub unsafe fn previouslyFocusedIndexPath(&self) -> Option<Retained<NSIndexPath>>
pub unsafe fn nextFocusedIndexPath(&self) -> Option<Retained<NSIndexPath>>
Methods from Deref<Target = UIFocusUpdateContext>
pub unsafe fn previouslyFocusedItem( &self ) -> Option<Retained<ProtocolObject<dyn UIFocusItem>>>
pub unsafe fn nextFocusedItem( &self ) -> Option<Retained<ProtocolObject<dyn UIFocusItem>>>
pub unsafe fn previouslyFocusedView(&self) -> Option<Retained<UIView>>
Available on crate features
UIResponder and UIView only.pub unsafe fn nextFocusedView(&self) -> Option<Retained<UIView>>
Available on crate features
UIResponder and UIView only.pub unsafe fn focusHeading(&self) -> UIFocusHeading
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.