Struct objc2_ui_kit::UIDynamicAnimator
source · #[repr(C)]pub struct UIDynamicAnimator { /* private fields */ }Available on crate feature
UIDynamicAnimator only.Implementations
sourceimpl UIDynamicAnimator
impl UIDynamicAnimator
pub unsafe fn initWithReferenceView( this: Allocated<Self>, view: &UIView ) -> Retained<Self>
Available on crate features
UIResponder and UIView only.pub unsafe fn addBehavior(&self, behavior: &UIDynamicBehavior)
Available on crate feature
UIDynamicBehavior only.pub unsafe fn removeBehavior(&self, behavior: &UIDynamicBehavior)
Available on crate feature
UIDynamicBehavior only.pub unsafe fn removeAllBehaviors(&self)
pub unsafe fn referenceView( &self, mtm: MainThreadMarker ) -> Option<Retained<UIView>>
Available on crate features
UIResponder and UIView only.pub unsafe fn behaviors( &self, mtm: MainThreadMarker ) -> Retained<NSArray<UIDynamicBehavior>>
Available on crate feature
UIDynamicBehavior only.pub unsafe fn itemsInRect( &self, rect: CGRect, mtm: MainThreadMarker ) -> Retained<NSArray<ProtocolObject<dyn UIDynamicItem>>>
Available on crate feature
UIDynamicBehavior only.pub unsafe fn updateItemUsingCurrentState( &self, item: &ProtocolObject<dyn UIDynamicItem> )
Available on crate feature
UIDynamicBehavior only.pub unsafe fn isRunning(&self) -> bool
pub unsafe fn elapsedTime(&self) -> NSTimeInterval
pub unsafe fn delegate( &self, mtm: MainThreadMarker ) -> Option<Retained<ProtocolObject<dyn UIDynamicAnimatorDelegate>>>
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn UIDynamicAnimatorDelegate>> )
sourceimpl UIDynamicAnimator
impl UIDynamicAnimator
Methods declared on superclass NSObject
sourceimpl UIDynamicAnimator
impl UIDynamicAnimator
UICollectionViewAdditions
pub unsafe fn initWithCollectionViewLayout( this: Allocated<Self>, layout: &UICollectionViewLayout ) -> Retained<Self>
Available on crate feature
UICollectionViewLayout only.pub unsafe fn layoutAttributesForCellAtIndexPath( &self, index_path: &NSIndexPath, mtm: MainThreadMarker ) -> Option<Retained<UICollectionViewLayoutAttributes>>
Available on crate feature
UICollectionViewLayout only.pub unsafe fn layoutAttributesForSupplementaryViewOfKind_atIndexPath( &self, kind: &NSString, index_path: &NSIndexPath, mtm: MainThreadMarker ) -> Option<Retained<UICollectionViewLayoutAttributes>>
Available on crate feature
UICollectionViewLayout only.pub unsafe fn layoutAttributesForDecorationViewOfKind_atIndexPath( &self, decoration_view_kind: &NSString, index_path: &NSIndexPath, mtm: MainThreadMarker ) -> Option<Retained<UICollectionViewLayoutAttributes>>
Available on crate feature
UICollectionViewLayout only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.