Struct objc2_ui_kit::UIFindInteraction
source · #[repr(C)]pub struct UIFindInteraction { /* private fields */ }Available on crate feature
UIFindInteraction only.Implementations
sourceimpl UIFindInteraction
impl UIFindInteraction
pub unsafe fn activeFindSession(&self) -> Option<Retained<UIFindSession>>
Available on crate feature
UIFindSession only.pub unsafe fn searchText(&self) -> Option<Retained<NSString>>
pub unsafe fn setSearchText(&self, search_text: Option<&NSString>)
pub unsafe fn replacementText(&self) -> Option<Retained<NSString>>
pub unsafe fn setReplacementText(&self, replacement_text: Option<&NSString>)
pub unsafe fn optionsMenuProvider( &self ) -> *mut Block<dyn Fn(NonNull<NSArray<UIMenuElement>>) -> *mut UIMenu>
Available on crate features
UIMenu and UIMenuElement and block2 only.pub unsafe fn setOptionsMenuProvider( &self, options_menu_provider: Option<&Block<dyn Fn(NonNull<NSArray<UIMenuElement>>) -> *mut UIMenu>> )
Available on crate features
UIMenu and UIMenuElement and block2 only.pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn UIFindInteractionDelegate>>>
pub unsafe fn initWithSessionDelegate( this: Allocated<Self>, session_delegate: &ProtocolObject<dyn UIFindInteractionDelegate> ) -> Retained<Self>
pub unsafe fn findNext(&self)
pub unsafe fn findPrevious(&self)
pub unsafe fn updateResultCount(&self)
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.