#[repr(C)]pub struct UIGraphicsImageRendererFormat { /* private fields */ }Available on crate features
UIGraphicsImageRenderer and UIGraphicsRenderer only.Implementations
sourceimpl UIGraphicsImageRendererFormat
impl UIGraphicsImageRendererFormat
pub unsafe fn scale(&self) -> CGFloat
pub unsafe fn setScale(&self, scale: CGFloat)
pub unsafe fn opaque(&self) -> bool
pub unsafe fn setOpaque(&self, opaque: bool)
pub unsafe fn prefersExtendedRange(&self) -> bool
👎Deprecated: Use the preferredRange property instead
pub unsafe fn setPrefersExtendedRange(&self, prefers_extended_range: bool)
👎Deprecated: Use the preferredRange property instead
pub unsafe fn supportsHighDynamicRange(&self) -> bool
pub unsafe fn preferredRange(&self) -> UIGraphicsImageRendererFormatRange
pub unsafe fn setPreferredRange( &self, preferred_range: UIGraphicsImageRendererFormatRange )
pub unsafe fn formatForTraitCollection( trait_collection: &UITraitCollection ) -> Retained<Self>
Available on crate feature
UITraitCollection only.sourceimpl UIGraphicsImageRendererFormat
impl UIGraphicsImageRendererFormat
Methods declared on superclass UIGraphicsRendererFormat
pub unsafe fn defaultFormat() -> Retained<Self>
👎Deprecated
pub unsafe fn preferredFormat() -> Retained<Self>
Methods from Deref<Target = UIGraphicsRendererFormat>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.