pub struct UIHoverEffectLayer { /* private fields */ }objc2-quartz-core and crate feature UIHoverEffectLayer and non-watchOS only.Expand description
A layer type that can be used to apply a hover effect to its sublayers.
This layer type is useful for adding hover effects to an existing
CALayer hierarchy. Where possible, use UIView.hoverStyle instead.
A UIHoverEffectLayer is configured with:
- A container
UIView, which is used to infer some properties of the hover effect from its trait collection and to allow some aspects of the hover effect to behave correctly. This view’s layer should be an ancestor layer of theUIHoverEffectLayer. - A
UIHoverStyle, which describes the effect to use and the shape of that effect. You then add your content layers that should receive a hover effect as sublayers of this layer.
UIHoverEffectLayer may add its own internal sublayers as background or
overlay layers relative to your content sublayers. To preserve the correct
appearance of the effect, these internal sublayers are automatically sorted
accordingly within the layer’s layout pass. As such, do not assume that the
indices of your content sublayers will remain stable throughout the lifetime
of the layer.
- Note: Not all
UIHoverStyles may be supported byUIHoverEffectLayer. If the provided style is not supported, a fallback style will be selected instead.
See also Apple’s documentation
Implementations
Sourceimpl UIHoverEffectLayer
impl UIHoverEffectLayer
Sourcepub fn hoverStyle(&self) -> Retained<UIHoverStyle>
Available on crate feature UIHoverStyle only.
pub fn hoverStyle(&self) -> Retained<UIHoverStyle>
UIHoverStyle only.The hover style to apply to the sublayers of this layer when this layer is hovered (e.g., when the user looks at this layer). Defaults to the automatic style.
- Note: Not all
UIHoverStyles may be supported byUIHoverEffectLayer. If the provided style is not supported, a fallback style will be selected instead.
Sourcepub fn setHoverStyle(&self, hover_style: &UIHoverStyle)
Available on crate feature UIHoverStyle only.
pub fn setHoverStyle(&self, hover_style: &UIHoverStyle)
UIHoverStyle only.Setter for hoverStyle.
This is copied when set.
Sourcepub fn containerView(&self) -> Option<Retained<UIView>>
Available on crate features UIResponder and UIView only.
pub fn containerView(&self) -> Option<Retained<UIView>>
UIResponder and UIView only.The UIView in which this layer is contained. This view is used to
derive traits and other properties for applying the correct hover effect
to the layer. It may also be used to assist with applying some kinds of
hover effects to the layer.
The containerView should be an ancestor of this layer (once it has
been added to a layer hierarchy) to behave correctly, but does not need
to be the immediate parent of this layer. If the containerView is
set to nil or is deallocated, some aspects of this layer’s hover effect
may no longer work correctly.
Sourcepub fn setContainerView(&self, container_view: Option<&UIView>)
Available on crate features UIResponder and UIView only.
pub fn setContainerView(&self, container_view: Option<&UIView>)
UIResponder and UIView only.Setter for containerView.
This is a weak property.
Sourcepub fn initWithContainerView_style(
this: Allocated<Self>,
container_view: &UIView,
style: Option<&UIHoverStyle>,
) -> Retained<Self>
Available on crate features UIHoverStyle and UIResponder and UIView only.
pub fn initWithContainerView_style( this: Allocated<Self>, container_view: &UIView, style: Option<&UIHoverStyle>, ) -> Retained<Self>
UIHoverStyle and UIResponder and UIView only.Creates a UIHoverEffectLayer with the provided containerView
and style. If a nil style is provided, the automatic style will
be used instead.
Sourceimpl UIHoverEffectLayer
Methods declared on superclass CALayer.
impl UIHoverEffectLayer
Methods declared on superclass CALayer.
Sourceimpl UIHoverEffectLayer
Methods declared on superclass NSObject.
impl UIHoverEffectLayer
Methods declared on superclass NSObject.
pub fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = CALayer>
pub unsafe fn presentationLayer(&self) -> Option<Retained<CALayer>>
pub unsafe fn modelLayer(&self) -> Retained<CALayer>
pub fn shouldArchiveValueForKey(&self, key: &NSString) -> bool
Sourcepub fn bounds(&self) -> CGRect
Available on crate feature objc2-core-foundation only.
pub fn bounds(&self) -> CGRect
objc2-core-foundation only.Geometry and layer hierarchy properties. *
Sourcepub fn setBounds(&self, bounds: CGRect)
Available on crate feature objc2-core-foundation only.
pub fn setBounds(&self, bounds: CGRect)
objc2-core-foundation only.Setter for bounds.
pub fn position(&self) -> CGPoint
objc2-core-foundation only.Sourcepub fn setPosition(&self, position: CGPoint)
Available on crate feature objc2-core-foundation only.
pub fn setPosition(&self, position: CGPoint)
objc2-core-foundation only.Setter for position.
pub fn zPosition(&self) -> f64
objc2-core-foundation only.Sourcepub fn setZPosition(&self, z_position: f64)
Available on crate feature objc2-core-foundation only.
pub fn setZPosition(&self, z_position: f64)
objc2-core-foundation only.Setter for zPosition.
pub fn anchorPoint(&self) -> CGPoint
objc2-core-foundation only.Sourcepub fn setAnchorPoint(&self, anchor_point: CGPoint)
Available on crate feature objc2-core-foundation only.
pub fn setAnchorPoint(&self, anchor_point: CGPoint)
objc2-core-foundation only.Setter for anchorPoint.
pub fn anchorPointZ(&self) -> f64
objc2-core-foundation only.Sourcepub fn setAnchorPointZ(&self, anchor_point_z: f64)
Available on crate feature objc2-core-foundation only.
pub fn setAnchorPointZ(&self, anchor_point_z: f64)
objc2-core-foundation only.Setter for anchorPointZ.
pub fn transform(&self) -> CATransform3D
CATransform3D and objc2-core-foundation only.Sourcepub fn setTransform(&self, transform: CATransform3D)
Available on crate features CATransform3D and objc2-core-foundation only.
pub fn setTransform(&self, transform: CATransform3D)
CATransform3D and objc2-core-foundation only.Setter for transform.
pub fn affineTransform(&self) -> CGAffineTransform
objc2-core-foundation only.pub fn setAffineTransform(&self, m: CGAffineTransform)
objc2-core-foundation only.pub fn frame(&self) -> CGRect
objc2-core-foundation only.Sourcepub fn setFrame(&self, frame: CGRect)
Available on crate feature objc2-core-foundation only.
pub fn setFrame(&self, frame: CGRect)
objc2-core-foundation only.Setter for frame.
pub fn isHidden(&self) -> bool
pub fn isDoubleSided(&self) -> bool
Sourcepub fn setDoubleSided(&self, double_sided: bool)
pub fn setDoubleSided(&self, double_sided: bool)
Setter for isDoubleSided.
pub fn isGeometryFlipped(&self) -> bool
Sourcepub fn setGeometryFlipped(&self, geometry_flipped: bool)
pub fn setGeometryFlipped(&self, geometry_flipped: bool)
Setter for isGeometryFlipped.
pub fn contentsAreFlipped(&self) -> bool
pub fn superlayer(&self) -> Option<Retained<CALayer>>
pub fn removeFromSuperlayer(&self)
pub unsafe fn sublayers(&self) -> Option<Retained<NSArray<CALayer>>>
Sourcepub unsafe fn setSublayers(&self, sublayers: Option<&NSArray<CALayer>>)
pub unsafe fn setSublayers(&self, sublayers: Option<&NSArray<CALayer>>)
pub fn addSublayer(&self, layer: &CALayer)
pub fn insertSublayer_atIndex(&self, layer: &CALayer, idx: u32)
pub fn insertSublayer_below(&self, layer: &CALayer, sibling: Option<&CALayer>)
pub fn insertSublayer_above(&self, layer: &CALayer, sibling: Option<&CALayer>)
pub unsafe fn replaceSublayer_with( &self, old_layer: &CALayer, new_layer: &CALayer, )
pub fn sublayerTransform(&self) -> CATransform3D
CATransform3D and objc2-core-foundation only.Sourcepub fn setSublayerTransform(&self, sublayer_transform: CATransform3D)
Available on crate features CATransform3D and objc2-core-foundation only.
pub fn setSublayerTransform(&self, sublayer_transform: CATransform3D)
CATransform3D and objc2-core-foundation only.Setter for sublayerTransform.
pub fn mask(&self) -> Option<Retained<CALayer>>
pub fn masksToBounds(&self) -> bool
Sourcepub fn setMasksToBounds(&self, masks_to_bounds: bool)
pub fn setMasksToBounds(&self, masks_to_bounds: bool)
Setter for masksToBounds.
Sourcepub fn convertPoint_fromLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint
Available on crate feature objc2-core-foundation only.
pub fn convertPoint_fromLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint
objc2-core-foundation only.Mapping between layer coordinate and time spaces. *
pub fn convertPoint_toLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint
objc2-core-foundation only.pub fn convertRect_fromLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect
objc2-core-foundation only.pub fn convertRect_toLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect
objc2-core-foundation only.pub fn convertTime_fromLayer(&self, t: f64, l: Option<&CALayer>) -> f64
objc2-core-foundation only.pub fn convertTime_toLayer(&self, t: f64, l: Option<&CALayer>) -> f64
objc2-core-foundation only.Sourcepub fn hitTest(&self, p: CGPoint) -> Option<Retained<CALayer>>
Available on crate feature objc2-core-foundation only.
pub fn hitTest(&self, p: CGPoint) -> Option<Retained<CALayer>>
objc2-core-foundation only.Hit testing methods. *
pub fn containsPoint(&self, p: CGPoint) -> bool
objc2-core-foundation only.Sourcepub unsafe fn contents(&self) -> Option<Retained<AnyObject>>
pub unsafe fn contents(&self) -> Option<Retained<AnyObject>>
Layer content properties and methods. *
Sourcepub unsafe fn setContents(&self, contents: Option<&AnyObject>)
pub unsafe fn setContents(&self, contents: Option<&AnyObject>)
pub fn contentsRect(&self) -> CGRect
objc2-core-foundation only.Sourcepub fn setContentsRect(&self, contents_rect: CGRect)
Available on crate feature objc2-core-foundation only.
pub fn setContentsRect(&self, contents_rect: CGRect)
objc2-core-foundation only.Setter for contentsRect.
pub fn contentsGravity(&self) -> Retained<NSString>
Sourcepub fn setContentsGravity(&self, contents_gravity: &NSString)
pub fn setContentsGravity(&self, contents_gravity: &NSString)
Setter for contentsGravity.
This is copied when set.
pub fn contentsScale(&self) -> f64
objc2-core-foundation only.Sourcepub fn setContentsScale(&self, contents_scale: f64)
Available on crate feature objc2-core-foundation only.
pub fn setContentsScale(&self, contents_scale: f64)
objc2-core-foundation only.Setter for contentsScale.
pub fn contentsCenter(&self) -> CGRect
objc2-core-foundation only.Sourcepub fn setContentsCenter(&self, contents_center: CGRect)
Available on crate feature objc2-core-foundation only.
pub fn setContentsCenter(&self, contents_center: CGRect)
objc2-core-foundation only.Setter for contentsCenter.
pub fn contentsFormat(&self) -> Retained<NSString>
Sourcepub fn setContentsFormat(&self, contents_format: &NSString)
pub fn setContentsFormat(&self, contents_format: &NSString)
Setter for contentsFormat.
This is copied when set.
pub fn wantsExtendedDynamicRangeContent(&self) -> bool
Use preferredDynamicRange instead
Sourcepub fn setWantsExtendedDynamicRangeContent(
&self,
wants_extended_dynamic_range_content: bool,
)
👎Deprecated: Use preferredDynamicRange instead
pub fn setWantsExtendedDynamicRangeContent( &self, wants_extended_dynamic_range_content: bool, )
Use preferredDynamicRange instead
Setter for wantsExtendedDynamicRangeContent.
pub fn toneMapMode(&self) -> Retained<NSString>
Sourcepub fn setToneMapMode(&self, tone_map_mode: &NSString)
pub fn setToneMapMode(&self, tone_map_mode: &NSString)
Setter for toneMapMode.
This is copied when set.
pub fn preferredDynamicRange(&self) -> Retained<NSString>
Sourcepub fn setPreferredDynamicRange(&self, preferred_dynamic_range: &NSString)
pub fn setPreferredDynamicRange(&self, preferred_dynamic_range: &NSString)
Setter for preferredDynamicRange.
This is copied when set.
pub fn contentsHeadroom(&self) -> f64
objc2-core-foundation only.Sourcepub fn setContentsHeadroom(&self, contents_headroom: f64)
Available on crate feature objc2-core-foundation only.
pub fn setContentsHeadroom(&self, contents_headroom: f64)
objc2-core-foundation only.Setter for contentsHeadroom.
pub fn wantsDynamicContentScaling(&self) -> bool
Sourcepub fn setWantsDynamicContentScaling(&self, wants_dynamic_content_scaling: bool)
pub fn setWantsDynamicContentScaling(&self, wants_dynamic_content_scaling: bool)
Setter for wantsDynamicContentScaling.
pub fn minificationFilter(&self) -> Retained<NSString>
Sourcepub fn setMinificationFilter(&self, minification_filter: &NSString)
pub fn setMinificationFilter(&self, minification_filter: &NSString)
Setter for minificationFilter.
This is copied when set.
pub fn magnificationFilter(&self) -> Retained<NSString>
Sourcepub fn setMagnificationFilter(&self, magnification_filter: &NSString)
pub fn setMagnificationFilter(&self, magnification_filter: &NSString)
Setter for magnificationFilter.
This is copied when set.
pub fn minificationFilterBias(&self) -> f32
Sourcepub fn setMinificationFilterBias(&self, minification_filter_bias: f32)
pub fn setMinificationFilterBias(&self, minification_filter_bias: f32)
Setter for minificationFilterBias.
pub fn isOpaque(&self) -> bool
pub fn display(&self)
pub fn setNeedsDisplay(&self)
pub fn setNeedsDisplayInRect(&self, r: CGRect)
objc2-core-foundation only.pub fn needsDisplay(&self) -> bool
pub fn displayIfNeeded(&self)
pub fn needsDisplayOnBoundsChange(&self) -> bool
Sourcepub fn setNeedsDisplayOnBoundsChange(
&self,
needs_display_on_bounds_change: bool,
)
pub fn setNeedsDisplayOnBoundsChange( &self, needs_display_on_bounds_change: bool, )
Setter for needsDisplayOnBoundsChange.
pub fn drawsAsynchronously(&self) -> bool
Sourcepub fn setDrawsAsynchronously(&self, draws_asynchronously: bool)
pub fn setDrawsAsynchronously(&self, draws_asynchronously: bool)
Setter for drawsAsynchronously.
pub fn edgeAntialiasingMask(&self) -> CAEdgeAntialiasingMask
Sourcepub fn setEdgeAntialiasingMask(
&self,
edge_antialiasing_mask: CAEdgeAntialiasingMask,
)
pub fn setEdgeAntialiasingMask( &self, edge_antialiasing_mask: CAEdgeAntialiasingMask, )
Setter for edgeAntialiasingMask.
pub fn allowsEdgeAntialiasing(&self) -> bool
Sourcepub fn setAllowsEdgeAntialiasing(&self, allows_edge_antialiasing: bool)
pub fn setAllowsEdgeAntialiasing(&self, allows_edge_antialiasing: bool)
Setter for allowsEdgeAntialiasing.
pub fn cornerRadius(&self) -> f64
objc2-core-foundation only.Sourcepub fn setCornerRadius(&self, corner_radius: f64)
Available on crate feature objc2-core-foundation only.
pub fn setCornerRadius(&self, corner_radius: f64)
objc2-core-foundation only.Setter for cornerRadius.
pub fn maskedCorners(&self) -> CACornerMask
Sourcepub fn setMaskedCorners(&self, masked_corners: CACornerMask)
pub fn setMaskedCorners(&self, masked_corners: CACornerMask)
Setter for maskedCorners.
pub fn cornerCurve(&self) -> Retained<NSString>
Sourcepub fn setCornerCurve(&self, corner_curve: &NSString)
pub fn setCornerCurve(&self, corner_curve: &NSString)
Setter for cornerCurve.
This is copied when set.
pub fn borderWidth(&self) -> f64
objc2-core-foundation only.Sourcepub fn setBorderWidth(&self, border_width: f64)
Available on crate feature objc2-core-foundation only.
pub fn setBorderWidth(&self, border_width: f64)
objc2-core-foundation only.Setter for borderWidth.
pub fn opacity(&self) -> f32
Sourcepub fn setOpacity(&self, opacity: f32)
pub fn setOpacity(&self, opacity: f32)
Setter for opacity.
pub fn allowsGroupOpacity(&self) -> bool
Sourcepub fn setAllowsGroupOpacity(&self, allows_group_opacity: bool)
pub fn setAllowsGroupOpacity(&self, allows_group_opacity: bool)
Setter for allowsGroupOpacity.
pub fn compositingFilter(&self) -> Option<Retained<AnyObject>>
Sourcepub unsafe fn setCompositingFilter(
&self,
compositing_filter: Option<&AnyObject>,
)
pub unsafe fn setCompositingFilter( &self, compositing_filter: Option<&AnyObject>, )
pub fn filters(&self) -> Option<Retained<NSArray>>
Sourcepub unsafe fn setFilters(&self, filters: Option<&NSArray>)
pub unsafe fn setFilters(&self, filters: Option<&NSArray>)
pub fn backgroundFilters(&self) -> Option<Retained<NSArray>>
Sourcepub unsafe fn setBackgroundFilters(&self, background_filters: Option<&NSArray>)
pub unsafe fn setBackgroundFilters(&self, background_filters: Option<&NSArray>)
Setter for backgroundFilters.
This is copied when set.
Safety
background_filters generic should be of the correct type.
pub fn shouldRasterize(&self) -> bool
Sourcepub fn setShouldRasterize(&self, should_rasterize: bool)
pub fn setShouldRasterize(&self, should_rasterize: bool)
Setter for shouldRasterize.
pub fn rasterizationScale(&self) -> f64
objc2-core-foundation only.Sourcepub fn setRasterizationScale(&self, rasterization_scale: f64)
Available on crate feature objc2-core-foundation only.
pub fn setRasterizationScale(&self, rasterization_scale: f64)
objc2-core-foundation only.Setter for rasterizationScale.
pub fn shadowOpacity(&self) -> f32
Sourcepub fn setShadowOpacity(&self, shadow_opacity: f32)
pub fn setShadowOpacity(&self, shadow_opacity: f32)
Setter for shadowOpacity.
pub fn shadowOffset(&self) -> CGSize
objc2-core-foundation only.Sourcepub fn setShadowOffset(&self, shadow_offset: CGSize)
Available on crate feature objc2-core-foundation only.
pub fn setShadowOffset(&self, shadow_offset: CGSize)
objc2-core-foundation only.Setter for shadowOffset.
pub fn shadowRadius(&self) -> f64
objc2-core-foundation only.Sourcepub fn setShadowRadius(&self, shadow_radius: f64)
Available on crate feature objc2-core-foundation only.
pub fn setShadowRadius(&self, shadow_radius: f64)
objc2-core-foundation only.Setter for shadowRadius.
Sourcepub fn autoresizingMask(&self) -> CAAutoresizingMask
pub fn autoresizingMask(&self) -> CAAutoresizingMask
Layout methods. *
Sourcepub fn setAutoresizingMask(&self, autoresizing_mask: CAAutoresizingMask)
pub fn setAutoresizingMask(&self, autoresizing_mask: CAAutoresizingMask)
Setter for autoresizingMask.
pub fn layoutManager( &self, ) -> Option<Retained<ProtocolObject<dyn CALayoutManager>>>
Sourcepub fn setLayoutManager(
&self,
layout_manager: Option<&ProtocolObject<dyn CALayoutManager>>,
)
pub fn setLayoutManager( &self, layout_manager: Option<&ProtocolObject<dyn CALayoutManager>>, )
Setter for layoutManager.
pub fn preferredFrameSize(&self) -> CGSize
objc2-core-foundation only.pub fn setNeedsLayout(&self)
pub fn needsLayout(&self) -> bool
pub fn layoutIfNeeded(&self)
pub fn layoutSublayers(&self)
pub fn resizeSublayersWithOldSize(&self, size: CGSize)
objc2-core-foundation only.pub fn resizeWithOldSuperlayerSize(&self, size: CGSize)
objc2-core-foundation only.pub fn actionForKey( &self, event: &NSString, ) -> Option<Retained<ProtocolObject<dyn CAAction>>>
pub fn actions( &self, ) -> Option<Retained<NSDictionary<NSString, ProtocolObject<dyn CAAction>>>>
Sourcepub fn setActions(
&self,
actions: Option<&NSDictionary<NSString, ProtocolObject<dyn CAAction>>>,
)
pub fn setActions( &self, actions: Option<&NSDictionary<NSString, ProtocolObject<dyn CAAction>>>, )
pub fn removeAllAnimations(&self)
pub fn removeAnimationForKey(&self, key: &NSString)
pub fn animationKeys(&self) -> Option<Retained<NSArray<NSString>>>
pub fn delegate(&self) -> Option<Retained<ProtocolObject<dyn CALayerDelegate>>>
Sourcepub fn setDelegate(
&self,
delegate: Option<&ProtocolObject<dyn CALayerDelegate>>,
)
pub fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CALayerDelegate>>, )
Setter for delegate.
This is a weak property.
pub fn style(&self) -> Option<Retained<NSDictionary>>
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
this is difficult to use correctly, use Ivar::load instead.
UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Available on crate feature UIIndirectScribbleInteraction only.
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
UIIndirectScribbleInteraction only.Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for UIHoverEffectLayer
impl AsRef<AnyObject> for UIHoverEffectLayer
Sourceimpl AsRef<CALayer> for UIHoverEffectLayer
impl AsRef<CALayer> for UIHoverEffectLayer
Sourceimpl AsRef<NSObject> for UIHoverEffectLayer
impl AsRef<NSObject> for UIHoverEffectLayer
Sourceimpl AsRef<UIHoverEffectLayer> for UIHoverEffectLayer
impl AsRef<UIHoverEffectLayer> for UIHoverEffectLayer
Sourceimpl Borrow<AnyObject> for UIHoverEffectLayer
impl Borrow<AnyObject> for UIHoverEffectLayer
Sourceimpl Borrow<CALayer> for UIHoverEffectLayer
impl Borrow<CALayer> for UIHoverEffectLayer
Sourceimpl Borrow<NSObject> for UIHoverEffectLayer
impl Borrow<NSObject> for UIHoverEffectLayer
Sourceimpl CAMediaTiming for UIHoverEffectLayer
impl CAMediaTiming for UIHoverEffectLayer
Sourcefn setBeginTime(&self, begin_time: f64)
fn setBeginTime(&self, begin_time: f64)
objc2-core-foundation only.beginTime.Sourcefn setDuration(&self, duration: f64)
fn setDuration(&self, duration: f64)
objc2-core-foundation only.duration.fn speed(&self) -> f32
Sourcefn timeOffset(&self) -> f64
fn timeOffset(&self) -> f64
objc2-core-foundation only.Sourcefn setTimeOffset(&self, time_offset: f64)
fn setTimeOffset(&self, time_offset: f64)
objc2-core-foundation only.timeOffset.fn repeatCount(&self) -> f32
Sourcefn setRepeatCount(&self, repeat_count: f32)
fn setRepeatCount(&self, repeat_count: f32)
repeatCount.Sourcefn repeatDuration(&self) -> f64
fn repeatDuration(&self) -> f64
objc2-core-foundation only.Sourcefn setRepeatDuration(&self, repeat_duration: f64)
fn setRepeatDuration(&self, repeat_duration: f64)
objc2-core-foundation only.repeatDuration.fn autoreverses(&self) -> bool
Sourcefn setAutoreverses(&self, autoreverses: bool)
fn setAutoreverses(&self, autoreverses: bool)
autoreverses.fn fillMode(&self) -> Retained<NSString>
Sourceimpl ClassType for UIHoverEffectLayer
impl ClassType for UIHoverEffectLayer
Sourceconst NAME: &'static str = "UIHoverEffectLayer"
const NAME: &'static str = "UIHoverEffectLayer"
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Debug for UIHoverEffectLayer
impl Debug for UIHoverEffectLayer
Sourceimpl Deref for UIHoverEffectLayer
impl Deref for UIHoverEffectLayer
Sourceimpl Hash for UIHoverEffectLayer
impl Hash for UIHoverEffectLayer
Sourceimpl Message for UIHoverEffectLayer
impl Message for UIHoverEffectLayer
Sourceimpl NSCoding for UIHoverEffectLayer
impl NSCoding for UIHoverEffectLayer
Sourceunsafe fn encodeWithCoder(&self, coder: &NSCoder)
unsafe fn encodeWithCoder(&self, coder: &NSCoder)
NSCoder only.Sourceimpl NSObjectProtocol for UIHoverEffectLayer
impl NSObjectProtocol for UIHoverEffectLayer
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
use isKindOfClass directly, or cast your objects with AnyObject::downcast_ref
Sourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl NSSecureCoding for UIHoverEffectLayer
impl NSSecureCoding for UIHoverEffectLayer
Sourceimpl PartialEq for UIHoverEffectLayer
impl PartialEq for UIHoverEffectLayer
Sourceimpl RefEncode for UIHoverEffectLayer
impl RefEncode for UIHoverEffectLayer
Sourceconst ENCODING_REF: Encoding = <CALayer as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <CALayer as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for UIHoverEffectLayer
impl Eq for UIHoverEffectLayer