#[repr(transparent)]pub struct UIImagePickerControllerSourceType(pub NSInteger);Available on crate feature
UIImagePickerController only.Expand description
Tuple Fields
0: NSIntegerImplementations
Sourceimpl UIImagePickerControllerSourceType
impl UIImagePickerControllerSourceType
pub const PhotoLibrary: Self
👎Deprecated:
Will be removed in a future release, use PHPicker.
pub const Camera: Self
pub const SavedPhotosAlbum: Self
👎Deprecated:
Will be removed in a future release, use PHPicker.