Struct objc2_ui_kit::UILayoutGuide
source · #[repr(C)]pub struct UILayoutGuide { /* private fields */ }Available on crate feature
UILayoutGuide only.Implementations
sourceimpl UILayoutGuide
impl UILayoutGuide
pub unsafe fn layoutFrame(&self) -> CGRect
pub unsafe fn owningView(&self) -> Option<Retained<UIView>>
Available on crate features
UIResponder and UIView only.pub unsafe fn setOwningView(&self, owning_view: Option<&UIView>)
Available on crate features
UIResponder and UIView only.pub unsafe fn identifier(&self) -> Retained<NSString>
pub unsafe fn setIdentifier(&self, identifier: &NSString)
pub unsafe fn leadingAnchor(&self) -> Retained<NSLayoutXAxisAnchor>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn trailingAnchor(&self) -> Retained<NSLayoutXAxisAnchor>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn leftAnchor(&self) -> Retained<NSLayoutXAxisAnchor>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn rightAnchor(&self) -> Retained<NSLayoutXAxisAnchor>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn topAnchor(&self) -> Retained<NSLayoutYAxisAnchor>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn bottomAnchor(&self) -> Retained<NSLayoutYAxisAnchor>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn widthAnchor(&self) -> Retained<NSLayoutDimension>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn heightAnchor(&self) -> Retained<NSLayoutDimension>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn centerXAnchor(&self) -> Retained<NSLayoutXAxisAnchor>
Available on crate feature
NSLayoutAnchor only.pub unsafe fn centerYAnchor(&self) -> Retained<NSLayoutYAxisAnchor>
Available on crate feature
NSLayoutAnchor only.sourceimpl UILayoutGuide
impl UILayoutGuide
Methods declared on superclass NSObject
impl UILayoutGuide
This impl block contains no items.
UIPopoverPresentationControllerSourceItem
sourceimpl UILayoutGuide
impl UILayoutGuide
UIConstraintBasedLayoutDebugging
pub unsafe fn constraintsAffectingLayoutForAxis( &self, axis: UILayoutConstraintAxis ) -> Retained<NSArray<NSLayoutConstraint>>
Available on crate features
UIView and NSLayoutConstraint only.pub unsafe fn hasAmbiguousLayout(&self) -> bool
Available on crate feature
UIView only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.