Struct objc2_ui_kit::UIPopoverController
source · #[repr(C)]pub struct UIPopoverController { /* private fields */ }👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate feature
UIPopoverController only.Implementations
sourceimpl UIPopoverController
impl UIPopoverController
pub unsafe fn initWithContentViewController( this: Allocated<Self>, view_controller: &UIViewController ) -> Retained<Self>
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate features
UIResponder and UIViewController only.pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn UIPopoverControllerDelegate>>>
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn UIPopoverControllerDelegate>> )
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
pub unsafe fn contentViewController(&self) -> Retained<UIViewController>
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate features
UIResponder and UIViewController only.pub unsafe fn setContentViewController( &self, content_view_controller: &UIViewController )
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate features
UIResponder and UIViewController only.pub unsafe fn setContentViewController_animated( &self, view_controller: &UIViewController, animated: bool )
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate features
UIResponder and UIViewController only.pub unsafe fn popoverContentSize(&self) -> CGSize
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
pub unsafe fn setPopoverContentSize(&self, popover_content_size: CGSize)
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
pub unsafe fn setPopoverContentSize_animated( &self, size: CGSize, animated: bool )
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
pub unsafe fn isPopoverVisible(&self) -> bool
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
pub unsafe fn popoverArrowDirection(&self) -> UIPopoverArrowDirection
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate feature
UIPopoverSupport only.pub unsafe fn passthroughViews(&self) -> Option<Retained<NSArray<UIView>>>
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate features
UIResponder and UIView only.pub unsafe fn setPassthroughViews( &self, passthrough_views: Option<&NSArray<UIView>> )
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate features
UIResponder and UIView only.pub unsafe fn presentPopoverFromRect_inView_permittedArrowDirections_animated( &self, rect: CGRect, view: &UIView, arrow_directions: UIPopoverArrowDirection, animated: bool )
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate features
UIPopoverSupport and UIResponder and UIView only.pub unsafe fn presentPopoverFromBarButtonItem_permittedArrowDirections_animated( &self, item: &UIBarButtonItem, arrow_directions: UIPopoverArrowDirection, animated: bool )
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
Available on crate features
UIBarButtonItem and UIBarItem and UIPopoverSupport only.pub unsafe fn dismissPopoverAnimated(&self, animated: bool)
👎Deprecated: UIPopoverController is deprecated. Popovers are now implemented as UIViewController presentations. Use a modal presentation style of UIModalPresentationPopover and UIPopoverPresentationController.
pub unsafe fn backgroundColor(&self) -> Option<Retained<UIColor>>
Available on crate feature
UIColor only.pub unsafe fn setBackgroundColor(&self, background_color: Option<&UIColor>)
Available on crate feature
UIColor only.pub unsafe fn popoverLayoutMargins(&self) -> UIEdgeInsets
Available on crate feature
UIGeometry only.pub unsafe fn setPopoverLayoutMargins( &self, popover_layout_margins: UIEdgeInsets )
Available on crate feature
UIGeometry only.pub unsafe fn popoverBackgroundViewClass(&self) -> Option<&'static AnyClass>
pub unsafe fn setPopoverBackgroundViewClass( &self, popover_background_view_class: Option<&AnyClass> )
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.