Struct objc2_ui_kit::UIPressesEvent
source · #[repr(C)]pub struct UIPressesEvent { /* private fields */ }Available on crate features
UIEvent and UIPressesEvent only.Implementations
sourceimpl UIPressesEvent
impl UIPressesEvent
pub unsafe fn allPresses(&self) -> Retained<NSSet<UIPress>>
Available on crate feature
UIPress only.pub unsafe fn pressesForGestureRecognizer( &self, gesture: &UIGestureRecognizer ) -> Retained<NSSet<UIPress>>
Available on crate features
UIGestureRecognizer and UIPress only.Methods from Deref<Target = UIEvent>
pub unsafe fn type(&self) -> UIEventType
pub unsafe fn subtype(&self) -> UIEventSubtype
pub unsafe fn timestamp(&self) -> NSTimeInterval
pub unsafe fn modifierFlags(&self) -> UIKeyModifierFlags
Available on crate feature
UICommand only.pub unsafe fn allTouches(&self) -> Option<Retained<NSSet<UITouch>>>
Available on crate feature
UITouch only.pub unsafe fn touchesForWindow( &self, window: &UIWindow ) -> Option<Retained<NSSet<UITouch>>>
Available on crate features
UIResponder and UITouch and UIView and UIWindow only.pub unsafe fn touchesForView( &self, view: &UIView ) -> Option<Retained<NSSet<UITouch>>>
Available on crate features
UIResponder and UITouch and UIView only.pub unsafe fn touchesForGestureRecognizer( &self, gesture: &UIGestureRecognizer ) -> Option<Retained<NSSet<UITouch>>>
Available on crate features
UIGestureRecognizer and UITouch only.pub unsafe fn coalescedTouchesForTouch( &self, touch: &UITouch ) -> Option<Retained<NSArray<UITouch>>>
Available on crate feature
UITouch only.pub unsafe fn predictedTouchesForTouch( &self, touch: &UITouch ) -> Option<Retained<NSArray<UITouch>>>
Available on crate feature
UITouch only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.