Struct objc2_ui_kit::UISpringLoadedInteraction
source · #[repr(C)]pub struct UISpringLoadedInteraction { /* private fields */ }Available on crate feature
UISpringLoadedInteraction only.Implementations
sourceimpl UISpringLoadedInteraction
impl UISpringLoadedInteraction
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithInteractionBehavior_interactionEffect_activationHandler( this: Allocated<Self>, interaction_behavior: Option<&ProtocolObject<dyn UISpringLoadedInteractionBehavior>>, interaction_effect: Option<&ProtocolObject<dyn UISpringLoadedInteractionEffect>>, handler: &Block<dyn Fn(NonNull<UISpringLoadedInteraction>, NonNull<ProtocolObject<dyn UISpringLoadedInteractionContext>>)> ) -> Retained<Self>
Available on crate feature
block2 only.pub unsafe fn initWithActivationHandler( this: Allocated<Self>, handler: &Block<dyn Fn(NonNull<UISpringLoadedInteraction>, NonNull<ProtocolObject<dyn UISpringLoadedInteractionContext>>)> ) -> Retained<Self>
Available on crate feature
block2 only.pub unsafe fn interactionBehavior( &self ) -> Retained<ProtocolObject<dyn UISpringLoadedInteractionBehavior>>
pub unsafe fn interactionEffect( &self ) -> Retained<ProtocolObject<dyn UISpringLoadedInteractionEffect>>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.