Struct objc2_ui_kit::UITabBarItem
source · #[repr(C)]pub struct UITabBarItem { /* private fields */ }Available on crate features
UIBarItem and UITabBarItem only.Implementations
impl UITabBarItem
This impl block contains no items.
UIPopoverPresentationControllerSourceItem
sourceimpl UITabBarItem
impl UITabBarItem
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder ) -> Option<Retained<Self>>
pub unsafe fn initWithTitle_image_tag( this: Allocated<Self>, title: Option<&NSString>, image: Option<&UIImage>, tag: NSInteger ) -> Retained<Self>
Available on crate feature
UIImage only.pub unsafe fn initWithTitle_image_selectedImage( this: Allocated<Self>, title: Option<&NSString>, image: Option<&UIImage>, selected_image: Option<&UIImage> ) -> Retained<Self>
Available on crate feature
UIImage only.pub unsafe fn initWithTabBarSystemItem_tag( this: Allocated<Self>, system_item: UITabBarSystemItem, tag: NSInteger ) -> Retained<Self>
pub unsafe fn selectedImage(&self) -> Option<Retained<UIImage>>
Available on crate feature
UIImage only.pub unsafe fn setSelectedImage(&self, selected_image: Option<&UIImage>)
Available on crate feature
UIImage only.pub unsafe fn badgeValue(&self) -> Option<Retained<NSString>>
pub unsafe fn setBadgeValue(&self, badge_value: Option<&NSString>)
pub unsafe fn setFinishedSelectedImage_withFinishedUnselectedImage( &self, selected_image: Option<&UIImage>, unselected_image: Option<&UIImage> )
👎Deprecated: Use initWithTitle:image:selectedImage: or the image and selectedImage properties along with UIImageRenderingModeAlwaysOriginal
Available on crate feature
UIImage only.pub unsafe fn finishedSelectedImage(&self) -> Option<Retained<UIImage>>
👎Deprecated
Available on crate feature
UIImage only.pub unsafe fn finishedUnselectedImage(&self) -> Option<Retained<UIImage>>
👎Deprecated
Available on crate feature
UIImage only.pub unsafe fn titlePositionAdjustment(&self) -> UIOffset
Available on crate feature
UIGeometry only.pub unsafe fn setTitlePositionAdjustment( &self, title_position_adjustment: UIOffset )
Available on crate feature
UIGeometry only.pub unsafe fn badgeColor(&self) -> Option<Retained<UIColor>>
Available on crate feature
UIColor only.pub unsafe fn setBadgeColor(&self, badge_color: Option<&UIColor>)
Available on crate feature
UIColor only.pub unsafe fn setBadgeTextAttributes_forState( &self, text_attributes: Option<&NSDictionary<NSAttributedStringKey, AnyObject>>, state: UIControlState )
Available on crate feature
UIControl only.pub unsafe fn badgeTextAttributesForState( &self, state: UIControlState ) -> Option<Retained<NSDictionary<NSAttributedStringKey, AnyObject>>>
Available on crate feature
UIControl only.pub unsafe fn standardAppearance(&self) -> Option<Retained<UITabBarAppearance>>
Available on crate features
UIBarAppearance and UITabBarAppearance only.pub unsafe fn setStandardAppearance( &self, standard_appearance: Option<&UITabBarAppearance> )
Available on crate features
UIBarAppearance and UITabBarAppearance only.pub unsafe fn scrollEdgeAppearance( &self ) -> Option<Retained<UITabBarAppearance>>
Available on crate features
UIBarAppearance and UITabBarAppearance only.pub unsafe fn setScrollEdgeAppearance( &self, scroll_edge_appearance: Option<&UITabBarAppearance> )
Available on crate features
UIBarAppearance and UITabBarAppearance only.sourceimpl UITabBarItem
impl UITabBarItem
Methods declared on superclass NSObject
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
impl UITabBarItem
This impl block contains no items.
SpringLoading
Methods from Deref<Target = UIBarItem>
pub unsafe fn isEnabled(&self) -> bool
pub unsafe fn setEnabled(&self, enabled: bool)
pub unsafe fn title(&self) -> Option<Retained<NSString>>
pub unsafe fn setTitle(&self, title: Option<&NSString>)
pub unsafe fn image(&self) -> Option<Retained<UIImage>>
Available on crate feature
UIImage only.pub unsafe fn setImage(&self, image: Option<&UIImage>)
Available on crate feature
UIImage only.pub unsafe fn landscapeImagePhone(&self) -> Option<Retained<UIImage>>
Available on crate feature
UIImage only.pub unsafe fn setLandscapeImagePhone( &self, landscape_image_phone: Option<&UIImage> )
Available on crate feature
UIImage only.pub unsafe fn largeContentSizeImage(&self) -> Option<Retained<UIImage>>
Available on crate feature
UIImage only.pub unsafe fn setLargeContentSizeImage( &self, large_content_size_image: Option<&UIImage> )
Available on crate feature
UIImage only.pub unsafe fn imageInsets(&self) -> UIEdgeInsets
Available on crate feature
UIGeometry only.pub unsafe fn setImageInsets(&self, image_insets: UIEdgeInsets)
Available on crate feature
UIGeometry only.pub unsafe fn landscapeImagePhoneInsets(&self) -> UIEdgeInsets
Available on crate feature
UIGeometry only.pub unsafe fn setLandscapeImagePhoneInsets( &self, landscape_image_phone_insets: UIEdgeInsets )
Available on crate feature
UIGeometry only.pub unsafe fn largeContentSizeImageInsets(&self) -> UIEdgeInsets
Available on crate feature
UIGeometry only.pub unsafe fn setLargeContentSizeImageInsets( &self, large_content_size_image_insets: UIEdgeInsets )
Available on crate feature
UIGeometry only.pub unsafe fn tag(&self) -> NSInteger
pub unsafe fn setTag(&self, tag: NSInteger)
pub unsafe fn setTitleTextAttributes_forState( &self, attributes: Option<&NSDictionary<NSAttributedStringKey, AnyObject>>, state: UIControlState )
Available on crate feature
UIControl only.pub unsafe fn titleTextAttributesForState( &self, state: UIControlState ) -> Option<Retained<NSDictionary<NSAttributedStringKey, AnyObject>>>
Available on crate feature
UIControl only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.