Struct objc2_ui_kit::UITextItemInteraction
source ยท #[repr(transparent)]pub struct UITextItemInteraction(pub NSInteger);๐Deprecated: UITextItemInteraction has been replaced by text item methods on UITextViewDelegate
Available on crate feature
UITextItemInteraction only.Tuple Fields
0: NSInteger๐Deprecated: UITextItemInteraction has been replaced by text item methods on UITextViewDelegate
Implementations
sourceimpl UITextItemInteraction
impl UITextItemInteraction
pub const InvokeDefaultAction: Self = _
๐Deprecated: UITextItemInteraction has been replaced by text item methods on UITextViewDelegate
pub const PresentActions: Self = _
๐Deprecated: UITextItemInteraction has been replaced by text item methods on UITextViewDelegate
pub const Preview: Self = _
๐Deprecated: UITextItemInteraction has been replaced by text item methods on UITextViewDelegate