Struct objc2_ui_kit::UIUserNotificationAction
source · #[repr(C)]pub struct UIUserNotificationAction { /* private fields */ }👎Deprecated: Use UserNotifications Framework’s UNNotificationAction
Available on crate feature
UIUserNotificationSettings only.Implementations
sourceimpl UIUserNotificationAction
impl UIUserNotificationAction
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder ) -> Option<Retained<Self>>
pub unsafe fn identifier(&self) -> Option<Retained<NSString>>
pub unsafe fn title(&self) -> Option<Retained<NSString>>
pub unsafe fn behavior(&self) -> UIUserNotificationActionBehavior
pub unsafe fn parameters(&self) -> Retained<NSDictionary>
pub unsafe fn activationMode(&self) -> UIUserNotificationActivationMode
pub unsafe fn isAuthenticationRequired(&self) -> bool
pub unsafe fn isDestructive(&self) -> bool
sourceimpl UIUserNotificationAction
impl UIUserNotificationAction
Methods declared on superclass NSObject
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.