UICalendarSelectionWeekOfYearDelegate

Trait UICalendarSelectionWeekOfYearDelegate 

pub unsafe trait UICalendarSelectionWeekOfYearDelegate: NSObjectProtocol + MainThreadOnly {
    // Provided methods
    fn weekOfYearSelection_didSelectWeekOfYear(
        &self,
        selection: &UICalendarSelectionWeekOfYear,
        week_of_year_components: Option<&NSDateComponents>,
    )
       where Self: Sized + Message { ... }
    fn weekOfYearSelection_canSelectWeekOfYear(
        &self,
        selection: &UICalendarSelectionWeekOfYear,
        week_of_year_components: Option<&NSDateComponents>,
    ) -> bool
       where Self: Sized + Message { ... }
}
Available on crate feature UICalendarSelectionWeekOfYear only.
Provided Methods

fn weekOfYearSelection_didSelectWeekOfYear( &self, selection: &UICalendarSelectionWeekOfYear, week_of_year_components: Option<&NSDateComponents>, )
where Self: Sized + Message,

Available on crate feature UICalendarSelection only.

Called after the user selects a week of year in the calendar view.

Parameter selection: The UICalendarSelectionWeekOfYear Parameter dateComponents: The date that was selected by the user.

fn weekOfYearSelection_canSelectWeekOfYear( &self, selection: &UICalendarSelectionWeekOfYear, week_of_year_components: Option<&NSDateComponents>, ) -> bool
where Self: Sized + Message,

Available on crate feature UICalendarSelection only.

Determines if a week of year is selectable. Dates that are not selectable will be disabled in the calendar view.

Parameter selection: The UICalendarSelectionWeekOfYear Parameter dateComponents: The date to be checked by selection.

Returns: YES if the date can be selected, NO otherwise.