pub unsafe trait UILargeContentViewerItem: NSObjectProtocol + MainThreadOnly {
// Provided methods
fn showsLargeContentViewer(&self) -> bool
where Self: Sized + Message { ... }
fn largeContentTitle(&self) -> Option<Retained<NSString>>
where Self: Sized + Message { ... }
fn largeContentImage(&self) -> Option<Retained<UIImage>>
where Self: Sized + Message { ... }
fn scalesLargeContentImage(&self) -> bool
where Self: Sized + Message { ... }
fn largeContentImageInsets(&self) -> UIEdgeInsets
where Self: Sized + Message { ... }
}UILargeContentViewer only.Expand description
Provided Methods
Sourcefn showsLargeContentViewer(&self) -> bool
fn showsLargeContentViewer(&self) -> bool
Returns whether the item shows the large content viewer. In general, only views that cannot scale for the full range of Dynamic Type sizes should return YES. For this property to take effect, the item or an ancestor view must have a UILargeContentViewerInteraction.
Sourcefn largeContentTitle(&self) -> Option<Retained<NSString>>
fn largeContentTitle(&self) -> Option<Retained<NSString>>
Returns a title that should be shown in the large content viewer.
Sourcefn largeContentImage(&self) -> Option<Retained<UIImage>>
Available on crate feature UIImage only.
fn largeContentImage(&self) -> Option<Retained<UIImage>>
UIImage only.Returns an image that should be shown in the large content viewer.
Sourcefn scalesLargeContentImage(&self) -> bool
fn scalesLargeContentImage(&self) -> bool
Returns whether the image should be scaled to a larger size appropriate for the viewer. If not, the image will be shown at its intrinsic size. For best results when scaling, use a PDF asset with its “Preserve Vector Data” checkbox checked.
Sourcefn largeContentImageInsets(&self) -> UIEdgeInsets
Available on crate features objc2-core-foundation and UIGeometry only.
fn largeContentImageInsets(&self) -> UIEdgeInsets
objc2-core-foundation and UIGeometry only.Returns insets appropriate for positioning the image in the viewer so that it appears visually centered.