pub unsafe trait UIPrinterPickerControllerDelegate: NSObjectProtocol + MainThreadOnly {
// Provided methods
fn printerPickerControllerParentViewController(
&self,
printer_picker_controller: &UIPrinterPickerController,
) -> Option<Retained<UIViewController>>
where Self: Sized + Message { ... }
fn printerPickerController_shouldShowPrinter(
&self,
printer_picker_controller: &UIPrinterPickerController,
printer: &UIPrinter,
) -> bool
where Self: Sized + Message { ... }
fn printerPickerControllerWillPresent(
&self,
printer_picker_controller: &UIPrinterPickerController,
)
where Self: Sized + Message { ... }
fn printerPickerControllerDidPresent(
&self,
printer_picker_controller: &UIPrinterPickerController,
)
where Self: Sized + Message { ... }
fn printerPickerControllerWillDismiss(
&self,
printer_picker_controller: &UIPrinterPickerController,
)
where Self: Sized + Message { ... }
fn printerPickerControllerDidDismiss(
&self,
printer_picker_controller: &UIPrinterPickerController,
)
where Self: Sized + Message { ... }
fn printerPickerControllerDidSelectPrinter(
&self,
printer_picker_controller: &UIPrinterPickerController,
)
where Self: Sized + Message { ... }
}Available on crate feature
UIPrinterPickerController only.Expand description
Provided Methods
fn printerPickerControllerParentViewController( &self, printer_picker_controller: &UIPrinterPickerController, ) -> Option<Retained<UIViewController>>
Available on crate features
UIResponder and UIViewController only.Sourcefn printerPickerController_shouldShowPrinter(
&self,
printer_picker_controller: &UIPrinterPickerController,
printer: &UIPrinter,
) -> bool
Available on crate feature UIPrinter only.
fn printerPickerController_shouldShowPrinter( &self, printer_picker_controller: &UIPrinterPickerController, printer: &UIPrinter, ) -> bool
UIPrinter only.Use to filter out specific printers from the printer picker. Evaluate the UIPrinter object and returns YES if the printer should be shown, NO otherwise. This delegate can assume that all UIPrinter properties are available (the contactPrinter: method need not be called). This method may be called from threads other than the main thread, and may be called simultaneously from several different threads.
fn printerPickerControllerWillPresent( &self, printer_picker_controller: &UIPrinterPickerController, )
fn printerPickerControllerDidPresent( &self, printer_picker_controller: &UIPrinterPickerController, )
fn printerPickerControllerWillDismiss( &self, printer_picker_controller: &UIPrinterPickerController, )
fn printerPickerControllerDidDismiss( &self, printer_picker_controller: &UIPrinterPickerController, )
fn printerPickerControllerDidSelectPrinter( &self, printer_picker_controller: &UIPrinterPickerController, )