pub unsafe trait UISpringLoadedInteractionEffect: NSObjectProtocol + MainThreadOnly {
// Provided method
fn interaction_didChangeWithContext(
&self,
interaction: &UISpringLoadedInteraction,
context: &ProtocolObject<dyn UISpringLoadedInteractionContext>,
)
where Self: Sized + Message { ... }
}Available on crate feature
UISpringLoadedInteraction only.Expand description
The interaction effect of a UISpringLoadedInteraction object must adopt the UISpringLoadedInteractionEffect protocol.
It is responsible for styling the interaction view according to the current springloading state.
See also Apple’s documentation
Provided Methods
Sourcefn interaction_didChangeWithContext(
&self,
interaction: &UISpringLoadedInteraction,
context: &ProtocolObject<dyn UISpringLoadedInteractionContext>,
)
fn interaction_didChangeWithContext( &self, interaction: &UISpringLoadedInteraction, context: &ProtocolObject<dyn UISpringLoadedInteractionContext>, )
Informs the effect that the springloading state changed.
Parameter interaction: The springloaded interaction providing this information.
Parameter context: An object that provides information about the current springloading state.