pub unsafe trait UITextSelectionDisplayInteractionDelegate: NSObjectProtocol + MainThreadOnly {
// Provided method
fn selectionContainerViewBelowTextForSelectionDisplayInteraction(
&self,
interaction: &UITextSelectionDisplayInteraction,
) -> Option<Retained<UIView>>
where Self: Sized + Message { ... }
}Available on crate feature
UITextSelectionDisplayInteraction only.Expand description
Provided Methods
Sourcefn selectionContainerViewBelowTextForSelectionDisplayInteraction(
&self,
interaction: &UITextSelectionDisplayInteraction,
) -> Option<Retained<UIView>>
Available on crate features UIResponder and UIView only.
fn selectionContainerViewBelowTextForSelectionDisplayInteraction( &self, interaction: &UITextSelectionDisplayInteraction, ) -> Option<Retained<UIView>>
UIResponder and UIView only.If different than the view that the interaction is installed onto, one can return a container view here for selection views that draw below text. Includes selection highlight view, etc. The default is assumed that all views are to be installed onto the interaction’s view.