pub unsafe trait UITextSelectionHandleView: UICoordinateSpace + MainThreadOnly {
// Provided methods
fn direction(&self) -> NSDirectionalRectEdge
where Self: Sized + Message { ... }
fn setDirection(&self, direction: NSDirectionalRectEdge)
where Self: Sized + Message { ... }
fn isVertical(&self) -> bool
where Self: Sized + Message { ... }
fn customShape(&self) -> Option<Retained<UIBezierPath>>
where Self: Sized + Message { ... }
fn setCustomShape(&self, custom_shape: Option<&UIBezierPath>)
where Self: Sized + Message { ... }
fn preferredFrameForRect(&self, rect: CGRect) -> CGRect
where Self: Sized + Message { ... }
}UITextSelectionHandleView and UIView only.Expand description
A view that represents a selection handle drawn at the edges of contiguous selection ranges.
When a selection is ranged (i.e., length is > 0), and the device supports range adjustment via a gesture, selection handles (“lollipops”) are displayed at the edges of the contiguous selection (usually a UITextSelectionHighlightView).
See also Apple’s documentation
Provided Methods
Sourcefn direction(&self) -> NSDirectionalRectEdge
Available on crate feature UIGeometry only.
fn direction(&self) -> NSDirectionalRectEdge
UIGeometry only.Controls which direction the handle is oriented. For example, NSDirectionalRectEdgeLeading indicates the handle is on the leading edge, so the dot will be rendered on top.
Sourcefn setDirection(&self, direction: NSDirectionalRectEdge)
Available on crate feature UIGeometry only.
fn setDirection(&self, direction: NSDirectionalRectEdge)
UIGeometry only.Setter for direction.
Sourcefn isVertical(&self) -> bool
fn isVertical(&self) -> bool
Convenience accessor for
directioncalculations.
Sourcefn customShape(&self) -> Option<Retained<UIBezierPath>>
Available on crate feature UIBezierPath only.
fn customShape(&self) -> Option<Retained<UIBezierPath>>
UIBezierPath only.If applicable, a custom shape for the lollipop stem. Default is
nil,which results in a rounded rect style based on bounds.
Sourcefn setCustomShape(&self, custom_shape: Option<&UIBezierPath>)
Available on crate feature UIBezierPath only.
fn setCustomShape(&self, custom_shape: Option<&UIBezierPath>)
UIBezierPath only.Setter for customShape.