UITextSelectionHighlightView

Trait UITextSelectionHighlightView 

pub unsafe trait UITextSelectionHighlightView: UICoordinateSpace + MainThreadOnly {
    // Provided methods
    fn selectionRects(&self) -> Retained<NSArray<UITextSelectionRect>>
       where Self: Sized + Message { ... }
    fn setSelectionRects(&self, selection_rects: &NSArray<UITextSelectionRect>)
       where Self: Sized + Message { ... }
}
Available on crate features UITextSelectionHighlightView and UIView only.
A view that displays a tinted highlight behind rendered text to indicate selection.

When a selection is ranged (i.e., length is > 0), a highlight view is shown to indicate the selected text range.

See also Apple’s documentation

Provided Methods

fn selectionRects(&self) -> Retained<NSArray<UITextSelectionRect>>
where Self: Sized + Message,

Available on crate feature UITextInput only.

A collection of UITextSelectionRectsrepresenting the geometry of the current selection. Rects are expected to be in the receiver’s coordinate space.

fn setSelectionRects(&self, selection_rects: &NSArray<UITextSelectionRect>)
where Self: Sized + Message,

Available on crate feature UITextInput only.

Setter for selectionRects.