pub unsafe trait UIWindowSceneDelegate: UISceneDelegate + MainThreadOnly {
// Provided methods
fn window(&self) -> Option<Retained<UIWindow>>
where Self: Sized + Message { ... }
fn setWindow(&self, window: Option<&UIWindow>)
where Self: Sized + Message { ... }
fn windowScene_didUpdateCoordinateSpace_interfaceOrientation_traitCollection(
&self,
window_scene: &UIWindowScene,
previous_coordinate_space: &ProtocolObject<dyn UICoordinateSpace>,
previous_interface_orientation: UIInterfaceOrientation,
previous_trait_collection: &UITraitCollection,
)
where Self: Sized + Message { ... }
fn windowScene_didUpdateEffectiveGeometry(
&self,
window_scene: &UIWindowScene,
previous_effective_geometry: &UIWindowSceneGeometry,
)
where Self: Sized + Message { ... }
fn windowScene_performActionForShortcutItem_completionHandler(
&self,
window_scene: &UIWindowScene,
shortcut_item: &UIApplicationShortcutItem,
completion_handler: &DynBlock<dyn Fn(Bool)>,
)
where Self: Sized + Message { ... }
fn windowScene_userDidAcceptCloudKitShareWithMetadata(
&self,
window_scene: &UIWindowScene,
cloud_kit_share_metadata: &CKShareMetadata,
)
where Self: Sized + Message { ... }
fn preferredWindowingControlStyleForScene(
&self,
window_scene: &UIWindowScene,
) -> Retained<UISceneWindowingControlStyle>
where Self: Sized + Message { ... }
}UIScene and UIWindowScene only.Expand description
Provided Methods
fn window(&self) -> Option<Retained<UIWindow>>
UIResponder and UIView and UIWindow only.Sourcefn setWindow(&self, window: Option<&UIWindow>)
Available on crate features UIResponder and UIView and UIWindow only.
fn setWindow(&self, window: Option<&UIWindow>)
UIResponder and UIView and UIWindow only.Setter for window.
Sourcefn windowScene_didUpdateCoordinateSpace_interfaceOrientation_traitCollection(
&self,
window_scene: &UIWindowScene,
previous_coordinate_space: &ProtocolObject<dyn UICoordinateSpace>,
previous_interface_orientation: UIInterfaceOrientation,
previous_trait_collection: &UITraitCollection,
)
👎Deprecated: Use windowScene(_: didUpdateEffectiveGeometry:) to be notified of the scene’s geometry changes, or use traits whose values are inherited from the scene via the traitCollection of views and view controllers instead.
Available on crate features UIOrientation and UIResponder and UITraitCollection and UIView only.
fn windowScene_didUpdateCoordinateSpace_interfaceOrientation_traitCollection( &self, window_scene: &UIWindowScene, previous_coordinate_space: &ProtocolObject<dyn UICoordinateSpace>, previous_interface_orientation: UIInterfaceOrientation, previous_trait_collection: &UITraitCollection, )
Use windowScene(_: didUpdateEffectiveGeometry:) to be notified of the scene’s geometry changes, or use traits whose values are inherited from the scene via the traitCollection of views and view controllers instead.
UIOrientation and UIResponder and UITraitCollection and UIView only.Called when the coordinate space, interface orientation, or trait collection of a UIWindowScene changes.
Always called when a UIWindowScene moves between screens.
Sourcefn windowScene_didUpdateEffectiveGeometry(
&self,
window_scene: &UIWindowScene,
previous_effective_geometry: &UIWindowSceneGeometry,
)
Available on crate features UIResponder and UIWindowSceneGeometry only.
fn windowScene_didUpdateEffectiveGeometry( &self, window_scene: &UIWindowScene, previous_effective_geometry: &UIWindowSceneGeometry, )
UIResponder and UIWindowSceneGeometry only.Called when the window scene’s effective geometry has changed.
Always called when a UIWindowScene moves between screens.
fn windowScene_performActionForShortcutItem_completionHandler( &self, window_scene: &UIWindowScene, shortcut_item: &UIApplicationShortcutItem, completion_handler: &DynBlock<dyn Fn(Bool)>, )
block2 and UIApplicationShortcutItem and UIResponder only.objc2-cloud-kit and UIResponder only.Sourcefn preferredWindowingControlStyleForScene(
&self,
window_scene: &UIWindowScene,
) -> Retained<UISceneWindowingControlStyle>
Available on crate features UIResponder and UISceneWindowingControlStyle only.
fn preferredWindowingControlStyleForScene( &self, window_scene: &UIWindowScene, ) -> Retained<UISceneWindowingControlStyle>
UIResponder and UISceneWindowingControlStyle only.Called by the system to determine the windowing control style for the provided scene.
automaticStyle will be used if this method is not implemented.