UICellAccessoryPosition

Type Alias UICellAccessoryPosition 

pub type UICellAccessoryPosition = *mut DynBlock<dyn Fn(NonNull<NSArray<UICellAccessory>>) -> NSUInteger>;
Available on crate features block2 and UICellAccessory only.
Return an index to insert the accessory at, given an array of the existing accessories on the edge (in leading to trailing order).

See also Apple’s documentation