UIContextMenuActionProvider

Type Alias UIContextMenuActionProvider 

pub type UIContextMenuActionProvider = *mut DynBlock<dyn Fn(NonNull<NSArray<UIMenuElement>>) -> *mut UIMenu>;
Available on crate features block2 and UIContextMenuConfiguration and UIMenu and UIMenuElement only.
Return a UIAction-based UIMenu describing the desired action hierarchy.

Parameter suggestedActions: An array of suggested actions gathered from the UIResponder chain. You may choose to include some of these actions in the hierarchy returned from this block to display them in the resulting menu.

See also Apple’s documentation