pub unsafe extern "C-unwind" fn UICellAccessoryPositionAfterAccessoryOfClass(
accessory_class: &AnyClass,
) -> UICellAccessoryPositionAvailable on crate features
UICellAccessory and block2 only.Expand description
Positions the accessory after the accessory matching the class specified, or at the end if not found.