pub unsafe extern "C-unwind" fn UICellAccessoryPositionBeforeAccessoryOfClass(
accessory_class: &AnyClass,
) -> UICellAccessoryPositionAvailable on crate features
UICellAccessory and block2 only.Expand description
Positions the accessory before the accessory matching the class specified, or at the beginning if not found.