Struct objc2_ui_kit::UIApplication
source · #[repr(C)]pub struct UIApplication { /* private fields */ }Available on crate features
UIApplication and UIResponder only.Implementations
sourceimpl UIApplication
impl UIApplication
pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn UIApplicationDelegate>>>
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn UIApplicationDelegate>> )
pub unsafe fn beginIgnoringInteractionEvents(&self)
👎Deprecated: Use UIView’s userInteractionEnabled property instead
pub unsafe fn endIgnoringInteractionEvents(&self)
👎Deprecated: Use UIView’s userInteractionEnabled property instead
pub unsafe fn isIgnoringInteractionEvents(&self) -> bool
👎Deprecated: Use UIView’s userInteractionEnabled property instead
pub unsafe fn isIdleTimerDisabled(&self) -> bool
pub unsafe fn setIdleTimerDisabled(&self, idle_timer_disabled: bool)
pub unsafe fn openURL(&self, url: &NSURL) -> bool
👎Deprecated
pub unsafe fn canOpenURL(&self, url: &NSURL) -> bool
pub unsafe fn openURL_options_completionHandler( &self, url: &NSURL, options: &NSDictionary<UIApplicationOpenExternalURLOptionsKey, AnyObject>, completion: Option<&Block<dyn Fn(Bool)>> )
Available on crate feature
block2 only.pub unsafe fn sendEvent(&self, event: &UIEvent)
Available on crate feature
UIEvent only.pub unsafe fn keyWindow(&self) -> Option<Retained<UIWindow>>
👎Deprecated: Should not be used for applications that support multiple scenes as it returns a key window across all connected scenes
Available on crate features
UIView and UIWindow only.pub fn windows(&self) -> Retained<NSArray<UIWindow>>
👎Deprecated: Use UIWindowScene.windows on a relevant window scene instead
Available on crate features
UIView and UIWindow only.pub unsafe fn sendAction_to_from_forEvent( &self, action: Sel, target: Option<&AnyObject>, sender: Option<&AnyObject>, event: Option<&UIEvent> ) -> bool
Available on crate feature
UIEvent only.pub unsafe fn isNetworkActivityIndicatorVisible(&self) -> bool
👎Deprecated: Provide a custom network activity UI in your app if desired.
pub unsafe fn setNetworkActivityIndicatorVisible( &self, network_activity_indicator_visible: bool )
👎Deprecated: Provide a custom network activity UI in your app if desired.
pub unsafe fn supportedInterfaceOrientationsForWindow( &self, window: Option<&UIWindow> ) -> UIInterfaceOrientationMask
Available on crate features
UIOrientation and UIView and UIWindow only.pub unsafe fn statusBarOrientationAnimationDuration(&self) -> NSTimeInterval
👎Deprecated: Use viewWillTransitionToSize:withTransitionCoordinator: instead.
pub fn statusBarFrame(&self) -> CGRect
👎Deprecated: Use the statusBarManager property of the window scene instead.
pub unsafe fn applicationIconBadgeNumber(&self) -> NSInteger
👎Deprecated: Use -[UNUserNotificationCenter setBadgeCount:withCompletionHandler:] instead.
pub unsafe fn setApplicationIconBadgeNumber( &self, application_icon_badge_number: NSInteger )
👎Deprecated: Use -[UNUserNotificationCenter setBadgeCount:withCompletionHandler:] instead.
pub unsafe fn applicationSupportsShakeToEdit(&self) -> bool
pub unsafe fn setApplicationSupportsShakeToEdit( &self, application_supports_shake_to_edit: bool )
pub unsafe fn applicationState(&self) -> UIApplicationState
pub unsafe fn backgroundTimeRemaining(&self) -> NSTimeInterval
pub unsafe fn beginBackgroundTaskWithExpirationHandler( &self, handler: Option<&Block<dyn Fn()>> ) -> UIBackgroundTaskIdentifier
Available on crate feature
block2 only.pub unsafe fn beginBackgroundTaskWithName_expirationHandler( &self, task_name: Option<&NSString>, handler: Option<&Block<dyn Fn()>> ) -> UIBackgroundTaskIdentifier
Available on crate feature
block2 only.pub unsafe fn endBackgroundTask(&self, identifier: UIBackgroundTaskIdentifier)
pub unsafe fn setMinimumBackgroundFetchInterval( &self, minimum_background_fetch_interval: NSTimeInterval )
👎Deprecated: Use a BGAppRefreshTask in the BackgroundTasks framework instead
pub unsafe fn backgroundRefreshStatus(&self) -> UIBackgroundRefreshStatus
pub unsafe fn isProtectedDataAvailable(&self) -> bool
pub unsafe fn userInterfaceLayoutDirection( &self ) -> UIUserInterfaceLayoutDirection
Available on crate feature
UIInterface only.pub unsafe fn preferredContentSizeCategory( &self ) -> Retained<UIContentSizeCategory>
Available on crate feature
UIContentSizeCategory only.pub unsafe fn connectedScenes(&self) -> Retained<NSSet<UIScene>>
Available on crate feature
UIScene only.pub unsafe fn openSessions(&self) -> Retained<NSSet<UISceneSession>>
Available on crate feature
UISceneSession only.pub unsafe fn supportsMultipleScenes(&self) -> bool
pub unsafe fn activateSceneSessionForRequest_errorHandler( &self, request: &UISceneSessionActivationRequest, error_handler: Option<&Block<dyn Fn(NonNull<NSError>)>> )
Available on crate features
UISceneSessionActivationRequest and block2 only.pub unsafe fn requestSceneSessionActivation_userActivity_options_errorHandler( &self, scene_session: Option<&UISceneSession>, user_activity: Option<&NSUserActivity>, options: Option<&UISceneActivationRequestOptions>, error_handler: Option<&Block<dyn Fn(NonNull<NSError>)>> )
👎Deprecated: Please use activateSceneSessionForRequest:errorHandler:
Available on crate features
UISceneOptions and UISceneSession and block2 only.pub unsafe fn requestSceneSessionDestruction_options_errorHandler( &self, scene_session: &UISceneSession, options: Option<&UISceneDestructionRequestOptions>, error_handler: Option<&Block<dyn Fn(NonNull<NSError>)>> )
Available on crate features
UISceneOptions and UISceneSession and block2 only.pub unsafe fn requestSceneSessionRefresh(&self, scene_session: &UISceneSession)
Available on crate feature
UISceneSession only.sourceimpl UIApplication
impl UIApplication
Methods declared on superclass NSObject
sourceimpl UIApplication
impl UIApplication
UIRemoteNotifications
pub unsafe fn registerForRemoteNotifications(&self)
pub unsafe fn unregisterForRemoteNotifications(&self)
pub unsafe fn isRegisteredForRemoteNotifications(&self) -> bool
pub unsafe fn registerForRemoteNotificationTypes( &self, types: UIRemoteNotificationType )
👎Deprecated: Use -[UIApplication registerForRemoteNotifications] and UserNotifications Framework’s -[UNUserNotificationCenter requestAuthorizationWithOptions:completionHandler:]
pub unsafe fn enabledRemoteNotificationTypes(&self) -> UIRemoteNotificationType
👎Deprecated: Use -[UIApplication isRegisteredForRemoteNotifications] and UserNotifications Framework’s -[UNUserNotificationCenter getNotificationSettingsWithCompletionHandler:] to retrieve user-enabled remote notification and user notification settings
sourceimpl UIApplication
impl UIApplication
UILocalNotifications
pub unsafe fn presentLocalNotificationNow( &self, notification: &UILocalNotification )
👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter addNotificationRequest:withCompletionHandler:]
Available on crate feature
UILocalNotification only.pub unsafe fn scheduleLocalNotification( &self, notification: &UILocalNotification )
👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter addNotificationRequest:withCompletionHandler:]
Available on crate feature
UILocalNotification only.pub unsafe fn cancelLocalNotification(&self, notification: &UILocalNotification)
👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter removePendingNotificationRequestsWithIdentifiers:]
Available on crate feature
UILocalNotification only.pub unsafe fn cancelAllLocalNotifications(&self)
👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter removeAllPendingNotificationRequests]
pub unsafe fn scheduledLocalNotifications( &self ) -> Option<Retained<NSArray<UILocalNotification>>>
👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter getPendingNotificationRequestsWithCompletionHandler:]
Available on crate feature
UILocalNotification only.pub unsafe fn setScheduledLocalNotifications( &self, scheduled_local_notifications: Option<&NSArray<UILocalNotification>> )
👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter getPendingNotificationRequestsWithCompletionHandler:]
Available on crate feature
UILocalNotification only.sourceimpl UIApplication
impl UIApplication
UIUserNotificationSettings
pub unsafe fn registerUserNotificationSettings( &self, notification_settings: &UIUserNotificationSettings )
👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter requestAuthorizationWithOptions:completionHandler:] and -[UNUserNotificationCenter setNotificationCategories:]
Available on crate feature
UIUserNotificationSettings only.pub unsafe fn currentUserNotificationSettings( &self ) -> Option<Retained<UIUserNotificationSettings>>
👎Deprecated: Use UserNotifications Framework’s -[UNUserNotificationCenter getNotificationSettingsWithCompletionHandler:] and -[UNUserNotificationCenter getNotificationCategoriesWithCompletionHandler:]
Available on crate feature
UIUserNotificationSettings only.sourceimpl UIApplication
impl UIApplication
UIRemoteControlEvents
pub unsafe fn beginReceivingRemoteControlEvents(&self)
pub unsafe fn endReceivingRemoteControlEvents(&self)
sourceimpl UIApplication
impl UIApplication
UINewsstand
pub unsafe fn setNewsstandIconImage(&self, image: Option<&UIImage>)
👎Deprecated: Newsstand apps now behave like normal apps on SpringBoard
Available on crate feature
UIImage only.sourceimpl UIApplication
impl UIApplication
UIShortcutItems
pub unsafe fn shortcutItems( &self ) -> Option<Retained<NSArray<UIApplicationShortcutItem>>>
Available on crate feature
UIApplicationShortcutItem only.pub unsafe fn setShortcutItems( &self, shortcut_items: Option<&NSArray<UIApplicationShortcutItem>> )
Available on crate feature
UIApplicationShortcutItem only.sourceimpl UIApplication
impl UIApplication
UIAlternateApplicationIcons
pub unsafe fn supportsAlternateIcons(&self) -> bool
pub unsafe fn setAlternateIconName_completionHandler( &self, alternate_icon_name: Option<&NSString>, completion_handler: Option<&Block<dyn Fn(*mut NSError)>> )
Available on crate feature
block2 only.pub unsafe fn alternateIconName(&self) -> Option<Retained<NSString>>
sourceimpl UIApplication
impl UIApplication
UIStateRestoration
pub unsafe fn extendStateRestoration(&self)
pub unsafe fn completeStateRestoration(&self)
pub unsafe fn ignoreSnapshotOnNextApplicationLaunch(&self)
pub unsafe fn registerObjectForStateRestoration_restorationIdentifier( object: &ProtocolObject<dyn UIStateRestoring>, restoration_identifier: &NSString )
Available on crate feature
UIStateRestoration only.sourceimpl UIApplication
impl UIApplication
UIApplicationDeprecated
pub unsafe fn isProximitySensingEnabled(&self) -> bool
👎Deprecated
pub unsafe fn setProximitySensingEnabled(&self, proximity_sensing_enabled: bool)
👎Deprecated
pub unsafe fn setStatusBarHidden_animated(&self, hidden: bool, animated: bool)
👎Deprecated: Use -[UIViewController prefersStatusBarHidden]
pub unsafe fn setStatusBarOrientation( &self, status_bar_orientation: UIInterfaceOrientation )
👎Deprecated: Explicit setting of the status bar orientation is more limited in iOS 6.0 and later
Available on crate feature
UIOrientation only.pub unsafe fn setStatusBarOrientation_animated( &self, interface_orientation: UIInterfaceOrientation, animated: bool )
👎Deprecated: Explicit setting of the status bar orientation is more limited in iOS 6.0 and later
Available on crate feature
UIOrientation only.pub unsafe fn setStatusBarStyle(&self, status_bar_style: UIStatusBarStyle)
👎Deprecated: Use -[UIViewController preferredStatusBarStyle]
pub unsafe fn setStatusBarStyle_animated( &self, status_bar_style: UIStatusBarStyle, animated: bool )
👎Deprecated: Use -[UIViewController preferredStatusBarStyle]
pub unsafe fn setStatusBarHidden(&self, status_bar_hidden: bool)
👎Deprecated: Use -[UIViewController prefersStatusBarHidden]
pub unsafe fn setStatusBarHidden_withAnimation( &self, hidden: bool, animation: UIStatusBarAnimation )
👎Deprecated: Use -[UIViewController prefersStatusBarHidden]
pub unsafe fn setKeepAliveTimeout_handler( &self, timeout: NSTimeInterval, keep_alive_handler: Option<&Block<dyn Fn()>> ) -> bool
👎Deprecated: Please use PushKit for VoIP applications instead of calling this method
Available on crate feature
block2 only.pub unsafe fn clearKeepAliveTimeout(&self)
👎Deprecated: Please use PushKit for VoIP applications instead of calling this method
Methods from Deref<Target = UIResponder>
pub unsafe fn nextResponder(&self) -> Option<Retained<UIResponder>>
pub unsafe fn canBecomeFirstResponder(&self) -> bool
pub unsafe fn becomeFirstResponder(&self) -> bool
pub unsafe fn canResignFirstResponder(&self) -> bool
pub unsafe fn resignFirstResponder(&self) -> bool
pub unsafe fn isFirstResponder(&self) -> bool
pub unsafe fn touchesBegan_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )
Available on crate features
UIEvent and UITouch only.pub unsafe fn touchesMoved_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )
Available on crate features
UIEvent and UITouch only.pub unsafe fn touchesEnded_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )
Available on crate features
UIEvent and UITouch only.pub unsafe fn touchesCancelled_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )
Available on crate features
UIEvent and UITouch only.pub unsafe fn touchesEstimatedPropertiesUpdated(&self, touches: &NSSet<UITouch>)
Available on crate feature
UITouch only.pub unsafe fn pressesBegan_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )
Available on crate features
UIEvent and UIPress and UIPressesEvent only.pub unsafe fn pressesChanged_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )
Available on crate features
UIEvent and UIPress and UIPressesEvent only.pub unsafe fn pressesEnded_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )
Available on crate features
UIEvent and UIPress and UIPressesEvent only.pub unsafe fn pressesCancelled_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )
Available on crate features
UIEvent and UIPress and UIPressesEvent only.pub unsafe fn motionBegan_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )
Available on crate feature
UIEvent only.pub unsafe fn motionEnded_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )
Available on crate feature
UIEvent only.pub unsafe fn motionCancelled_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )
Available on crate feature
UIEvent only.pub unsafe fn remoteControlReceivedWithEvent(&self, event: Option<&UIEvent>)
Available on crate feature
UIEvent only.pub unsafe fn canPerformAction_withSender( &self, action: Sel, sender: Option<&AnyObject> ) -> bool
pub unsafe fn targetForAction_withSender( &self, action: Sel, sender: Option<&AnyObject> ) -> Option<Retained<AnyObject>>
pub unsafe fn buildMenuWithBuilder( &self, builder: &ProtocolObject<dyn UIMenuBuilder> )
Available on crate feature
UIMenuBuilder only.pub unsafe fn validateCommand(&self, command: &UICommand)
Available on crate features
UICommand and UIMenuElement only.pub unsafe fn undoManager(&self) -> Option<Retained<NSUndoManager>>
pub unsafe fn editingInteractionConfiguration( &self ) -> UIEditingInteractionConfiguration
pub unsafe fn keyCommands(&self) -> Option<Retained<NSArray<UIKeyCommand>>>
Available on crate features
UICommand and UIKeyCommand and UIMenuElement only.pub unsafe fn inputView(&self) -> Option<Retained<UIView>>
Available on crate feature
UIView only.pub unsafe fn inputAccessoryView(&self) -> Option<Retained<UIView>>
Available on crate feature
UIView only.pub unsafe fn inputAssistantItem(&self) -> Retained<UITextInputAssistantItem>
Available on crate feature
UITextInput only.pub unsafe fn inputViewController( &self ) -> Option<Retained<UIInputViewController>>
Available on crate features
UIInputViewController and UIViewController only.pub unsafe fn inputAccessoryViewController( &self ) -> Option<Retained<UIInputViewController>>
Available on crate features
UIInputViewController and UIViewController only.pub unsafe fn textInputMode(&self) -> Option<Retained<UITextInputMode>>
Available on crate feature
UITextInput only.pub unsafe fn textInputContextIdentifier(&self) -> Option<Retained<NSString>>
pub unsafe fn reloadInputViews(&self)
pub unsafe fn userActivity(&self) -> Option<Retained<NSUserActivity>>
pub unsafe fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)
pub unsafe fn updateUserActivityState(&self, activity: &NSUserActivity)
pub unsafe fn restoreUserActivityState(&self, activity: &NSUserActivity)
pub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)
pub unsafe fn activityItemsConfiguration( &self ) -> Option<Retained<ProtocolObject<dyn UIActivityItemsConfigurationReading>>>
Available on crate features
UIResponder_UIActivityItemsConfiguration and UIActivityItemsConfigurationReading only.pub unsafe fn setActivityItemsConfiguration( &self, activity_items_configuration: Option<&ProtocolObject<dyn UIActivityItemsConfigurationReading>> )
Available on crate features
UIResponder_UIActivityItemsConfiguration and UIActivityItemsConfigurationReading only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.