Struct objc2_ui_kit::UIHoverEffectLayer

source ·
#[repr(C)]
pub struct UIHoverEffectLayer { /* private fields */ }
Available on crate feature UIHoverEffectLayer and crate feature objc2-quartz-core and non-watchOS only.

Implementations

source

impl UIHoverEffectLayer

source

pub unsafe fn hoverStyle(&self) -> Retained<UIHoverStyle>

Available on crate feature UIHoverStyle only.
source

pub unsafe fn setHoverStyle(&self, hover_style: &UIHoverStyle)

Available on crate feature UIHoverStyle only.
source

pub unsafe fn containerView(&self) -> Option<Retained<UIView>>

Available on crate features UIResponder and UIView only.
source

pub unsafe fn setContainerView(&self, container_view: Option<&UIView>)

Available on crate features UIResponder and UIView only.
source

pub unsafe fn initWithContainerView_style( this: Allocated<Self>, container_view: &UIView, style: Option<&UIHoverStyle> ) -> Retained<Self>

Available on crate features UIHoverStyle and UIResponder and UIView only.
source

impl UIHoverEffectLayer

Methods declared on superclass CALayer

source

pub unsafe fn layer(mtm: MainThreadMarker) -> Retained<Self>

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn initWithLayer( this: Allocated<Self>, layer: &AnyObject ) -> Retained<Self>

source

impl UIHoverEffectLayer

Methods declared on superclass NSObject

source

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Methods from Deref<Target = CALayer>

source

pub unsafe fn presentationLayer(&self) -> Option<Retained<CALayer>>

source

pub unsafe fn modelLayer(&self) -> Retained<CALayer>

source

pub unsafe fn shouldArchiveValueForKey(&self, key: &NSString) -> bool

source

pub fn bounds(&self) -> CGRect

source

pub fn setBounds(&self, bounds: CGRect)

source

pub fn position(&self) -> CGPoint

source

pub fn setPosition(&self, position: CGPoint)

source

pub fn zPosition(&self) -> f64

source

pub fn setZPosition(&self, z_position: f64)

source

pub fn anchorPoint(&self) -> CGPoint

source

pub fn setAnchorPoint(&self, anchor_point: CGPoint)

source

pub fn anchorPointZ(&self) -> f64

source

pub fn setAnchorPointZ(&self, anchor_point_z: f64)

source

pub fn transform(&self) -> CATransform3D

Available on crate feature CATransform3D only.
source

pub fn setTransform(&self, transform: CATransform3D)

Available on crate feature CATransform3D only.
source

pub fn frame(&self) -> CGRect

source

pub fn setFrame(&self, frame: CGRect)

source

pub fn isHidden(&self) -> bool

source

pub fn setHidden(&self, hidden: bool)

source

pub fn isDoubleSided(&self) -> bool

source

pub fn setDoubleSided(&self, double_sided: bool)

source

pub fn isGeometryFlipped(&self) -> bool

source

pub fn setGeometryFlipped(&self, geometry_flipped: bool)

source

pub fn contentsAreFlipped(&self) -> bool

source

pub fn superlayer(&self) -> Option<Retained<CALayer>>

source

pub fn removeFromSuperlayer(&self)

source

pub unsafe fn sublayers(&self) -> Option<Retained<NSArray<CALayer>>>

source

pub unsafe fn setSublayers(&self, sublayers: Option<&NSArray<CALayer>>)

source

pub fn addSublayer(&self, layer: &CALayer)

source

pub fn insertSublayer_atIndex(&self, layer: &CALayer, idx: u32)

source

pub fn insertSublayer_below(&self, layer: &CALayer, sibling: Option<&CALayer>)

source

pub fn insertSublayer_above(&self, layer: &CALayer, sibling: Option<&CALayer>)

source

pub unsafe fn replaceSublayer_with( &self, old_layer: &CALayer, new_layer: &CALayer )

source

pub fn sublayerTransform(&self) -> CATransform3D

Available on crate feature CATransform3D only.
source

pub fn setSublayerTransform(&self, sublayer_transform: CATransform3D)

Available on crate feature CATransform3D only.
source

pub fn mask(&self) -> Option<Retained<CALayer>>

source

pub unsafe fn setMask(&self, mask: Option<&CALayer>)

source

pub fn masksToBounds(&self) -> bool

source

pub fn setMasksToBounds(&self, masks_to_bounds: bool)

source

pub fn convertPoint_fromLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint

source

pub fn convertPoint_toLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint

source

pub fn convertRect_fromLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect

source

pub fn convertRect_toLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect

source

pub fn convertTime_fromLayer(&self, t: f64, l: Option<&CALayer>) -> f64

source

pub fn convertTime_toLayer(&self, t: f64, l: Option<&CALayer>) -> f64

source

pub fn hitTest(&self, p: CGPoint) -> Option<Retained<CALayer>>

source

pub fn containsPoint(&self, p: CGPoint) -> bool

source

pub unsafe fn contents(&self) -> Option<Retained<AnyObject>>

source

pub unsafe fn setContents(&self, contents: Option<&AnyObject>)

source

pub fn contentsRect(&self) -> CGRect

source

pub fn setContentsRect(&self, contents_rect: CGRect)

source

pub fn contentsGravity(&self) -> Retained<NSString>

source

pub fn setContentsGravity(&self, contents_gravity: &NSString)

source

pub fn contentsScale(&self) -> f64

source

pub fn setContentsScale(&self, contents_scale: f64)

source

pub fn contentsCenter(&self) -> CGRect

source

pub fn setContentsCenter(&self, contents_center: CGRect)

source

pub fn contentsFormat(&self) -> Retained<NSString>

source

pub fn setContentsFormat(&self, contents_format: &NSString)

source

pub unsafe fn wantsExtendedDynamicRangeContent(&self) -> bool

source

pub unsafe fn setWantsExtendedDynamicRangeContent( &self, wants_extended_dynamic_range_content: bool )

source

pub fn minificationFilter(&self) -> Retained<NSString>

source

pub fn setMinificationFilter(&self, minification_filter: &NSString)

source

pub fn magnificationFilter(&self) -> Retained<NSString>

source

pub fn setMagnificationFilter(&self, magnification_filter: &NSString)

source

pub fn minificationFilterBias(&self) -> f32

source

pub fn setMinificationFilterBias(&self, minification_filter_bias: f32)

source

pub fn isOpaque(&self) -> bool

source

pub fn setOpaque(&self, opaque: bool)

source

pub fn display(&self)

source

pub fn setNeedsDisplay(&self)

source

pub fn setNeedsDisplayInRect(&self, r: CGRect)

source

pub fn needsDisplay(&self) -> bool

source

pub fn displayIfNeeded(&self)

source

pub fn needsDisplayOnBoundsChange(&self) -> bool

source

pub fn setNeedsDisplayOnBoundsChange( &self, needs_display_on_bounds_change: bool )

source

pub fn drawsAsynchronously(&self) -> bool

source

pub fn setDrawsAsynchronously(&self, draws_asynchronously: bool)

source

pub fn edgeAntialiasingMask(&self) -> CAEdgeAntialiasingMask

source

pub fn setEdgeAntialiasingMask( &self, edge_antialiasing_mask: CAEdgeAntialiasingMask )

source

pub fn allowsEdgeAntialiasing(&self) -> bool

source

pub fn setAllowsEdgeAntialiasing(&self, allows_edge_antialiasing: bool)

source

pub fn cornerRadius(&self) -> f64

source

pub fn setCornerRadius(&self, corner_radius: f64)

source

pub fn maskedCorners(&self) -> CACornerMask

source

pub fn setMaskedCorners(&self, masked_corners: CACornerMask)

source

pub fn cornerCurve(&self) -> Retained<NSString>

source

pub fn setCornerCurve(&self, corner_curve: &NSString)

source

pub fn borderWidth(&self) -> f64

source

pub fn setBorderWidth(&self, border_width: f64)

source

pub fn opacity(&self) -> f32

source

pub fn setOpacity(&self, opacity: f32)

source

pub fn allowsGroupOpacity(&self) -> bool

source

pub fn setAllowsGroupOpacity(&self, allows_group_opacity: bool)

source

pub unsafe fn compositingFilter(&self) -> Option<Retained<AnyObject>>

source

pub unsafe fn setCompositingFilter( &self, compositing_filter: Option<&AnyObject> )

source

pub unsafe fn filters(&self) -> Option<Retained<NSArray>>

source

pub unsafe fn setFilters(&self, filters: Option<&NSArray>)

source

pub unsafe fn backgroundFilters(&self) -> Option<Retained<NSArray>>

source

pub unsafe fn setBackgroundFilters(&self, background_filters: Option<&NSArray>)

source

pub fn shouldRasterize(&self) -> bool

source

pub fn setShouldRasterize(&self, should_rasterize: bool)

source

pub fn rasterizationScale(&self) -> f64

source

pub fn setRasterizationScale(&self, rasterization_scale: f64)

source

pub fn shadowOpacity(&self) -> f32

source

pub fn setShadowOpacity(&self, shadow_opacity: f32)

source

pub fn shadowOffset(&self) -> CGSize

source

pub fn setShadowOffset(&self, shadow_offset: CGSize)

source

pub fn shadowRadius(&self) -> f64

source

pub fn setShadowRadius(&self, shadow_radius: f64)

source

pub fn autoresizingMask(&self) -> CAAutoresizingMask

source

pub fn setAutoresizingMask(&self, autoresizing_mask: CAAutoresizingMask)

source

pub fn layoutManager( &self ) -> Option<Retained<ProtocolObject<dyn CALayoutManager>>>

source

pub fn setLayoutManager( &self, layout_manager: Option<&ProtocolObject<dyn CALayoutManager>> )

source

pub fn preferredFrameSize(&self) -> CGSize

source

pub fn setNeedsLayout(&self)

source

pub fn needsLayout(&self) -> bool

source

pub fn layoutIfNeeded(&self)

source

pub fn layoutSublayers(&self)

source

pub fn resizeSublayersWithOldSize(&self, size: CGSize)

source

pub fn resizeWithOldSuperlayerSize(&self, size: CGSize)

source

pub fn actionForKey( &self, event: &NSString ) -> Option<Retained<ProtocolObject<dyn CAAction>>>

source

pub fn actions( &self ) -> Option<Retained<NSDictionary<NSString, ProtocolObject<dyn CAAction>>>>

source

pub fn setActions( &self, actions: Option<&NSDictionary<NSString, ProtocolObject<dyn CAAction>>> )

source

pub fn removeAllAnimations(&self)

source

pub fn removeAnimationForKey(&self, key: &NSString)

source

pub fn animationKeys(&self) -> Option<Retained<NSArray<NSString>>>

source

pub fn name(&self) -> Option<Retained<NSString>>

source

pub fn setName(&self, name: Option<&NSString>)

source

pub fn delegate(&self) -> Option<Retained<ProtocolObject<dyn CALayerDelegate>>>

source

pub fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CALayerDelegate>> )

source

pub unsafe fn style(&self) -> Option<Retained<NSDictionary>>

source

pub unsafe fn setStyle(&self, style: Option<&NSDictionary>)

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Available on crate feature UIIndirectScribbleInteraction only.

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
Available on crate feature UIIndirectScribbleInteraction only.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
Available on crate feature UIIndirectScribbleInteraction only.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.