Struct objc2_ui_kit::UIHoverEffectLayer
source · #[repr(C)]pub struct UIHoverEffectLayer { /* private fields */ }Available on crate feature
UIHoverEffectLayer and crate feature objc2-quartz-core and non-watchOS only.Implementations
sourceimpl UIHoverEffectLayer
impl UIHoverEffectLayer
pub unsafe fn hoverStyle(&self) -> Retained<UIHoverStyle>
Available on crate feature
UIHoverStyle only.pub unsafe fn setHoverStyle(&self, hover_style: &UIHoverStyle)
Available on crate feature
UIHoverStyle only.pub unsafe fn containerView(&self) -> Option<Retained<UIView>>
Available on crate features
UIResponder and UIView only.pub unsafe fn setContainerView(&self, container_view: Option<&UIView>)
Available on crate features
UIResponder and UIView only.pub unsafe fn initWithContainerView_style( this: Allocated<Self>, container_view: &UIView, style: Option<&UIHoverStyle> ) -> Retained<Self>
Available on crate features
UIHoverStyle and UIResponder and UIView only.sourceimpl UIHoverEffectLayer
impl UIHoverEffectLayer
Methods declared on superclass CALayer
sourceimpl UIHoverEffectLayer
impl UIHoverEffectLayer
Methods declared on superclass NSObject
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = CALayer>
pub unsafe fn presentationLayer(&self) -> Option<Retained<CALayer>>
pub unsafe fn modelLayer(&self) -> Retained<CALayer>
pub unsafe fn shouldArchiveValueForKey(&self, key: &NSString) -> bool
pub fn bounds(&self) -> CGRect
pub fn setBounds(&self, bounds: CGRect)
pub fn position(&self) -> CGPoint
pub fn setPosition(&self, position: CGPoint)
pub fn zPosition(&self) -> f64
pub fn setZPosition(&self, z_position: f64)
pub fn anchorPoint(&self) -> CGPoint
pub fn setAnchorPoint(&self, anchor_point: CGPoint)
pub fn anchorPointZ(&self) -> f64
pub fn setAnchorPointZ(&self, anchor_point_z: f64)
pub fn transform(&self) -> CATransform3D
Available on crate feature
CATransform3D only.pub fn setTransform(&self, transform: CATransform3D)
Available on crate feature
CATransform3D only.pub fn frame(&self) -> CGRect
pub fn setFrame(&self, frame: CGRect)
pub fn isHidden(&self) -> bool
pub fn setHidden(&self, hidden: bool)
pub fn isDoubleSided(&self) -> bool
pub fn setDoubleSided(&self, double_sided: bool)
pub fn isGeometryFlipped(&self) -> bool
pub fn setGeometryFlipped(&self, geometry_flipped: bool)
pub fn contentsAreFlipped(&self) -> bool
pub fn superlayer(&self) -> Option<Retained<CALayer>>
pub fn removeFromSuperlayer(&self)
pub unsafe fn sublayers(&self) -> Option<Retained<NSArray<CALayer>>>
pub unsafe fn setSublayers(&self, sublayers: Option<&NSArray<CALayer>>)
pub fn addSublayer(&self, layer: &CALayer)
pub fn insertSublayer_atIndex(&self, layer: &CALayer, idx: u32)
pub fn insertSublayer_below(&self, layer: &CALayer, sibling: Option<&CALayer>)
pub fn insertSublayer_above(&self, layer: &CALayer, sibling: Option<&CALayer>)
pub unsafe fn replaceSublayer_with( &self, old_layer: &CALayer, new_layer: &CALayer )
pub fn sublayerTransform(&self) -> CATransform3D
Available on crate feature
CATransform3D only.pub fn setSublayerTransform(&self, sublayer_transform: CATransform3D)
Available on crate feature
CATransform3D only.pub fn mask(&self) -> Option<Retained<CALayer>>
pub unsafe fn setMask(&self, mask: Option<&CALayer>)
pub fn masksToBounds(&self) -> bool
pub fn setMasksToBounds(&self, masks_to_bounds: bool)
pub fn convertPoint_fromLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint
pub fn convertPoint_toLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint
pub fn convertRect_fromLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect
pub fn convertRect_toLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect
pub fn convertTime_fromLayer(&self, t: f64, l: Option<&CALayer>) -> f64
pub fn convertTime_toLayer(&self, t: f64, l: Option<&CALayer>) -> f64
pub fn hitTest(&self, p: CGPoint) -> Option<Retained<CALayer>>
pub fn containsPoint(&self, p: CGPoint) -> bool
pub unsafe fn contents(&self) -> Option<Retained<AnyObject>>
pub unsafe fn setContents(&self, contents: Option<&AnyObject>)
pub fn contentsRect(&self) -> CGRect
pub fn setContentsRect(&self, contents_rect: CGRect)
pub fn contentsGravity(&self) -> Retained<NSString>
pub fn setContentsGravity(&self, contents_gravity: &NSString)
pub fn contentsScale(&self) -> f64
pub fn setContentsScale(&self, contents_scale: f64)
pub fn contentsCenter(&self) -> CGRect
pub fn setContentsCenter(&self, contents_center: CGRect)
pub fn contentsFormat(&self) -> Retained<NSString>
pub fn setContentsFormat(&self, contents_format: &NSString)
pub unsafe fn wantsExtendedDynamicRangeContent(&self) -> bool
pub unsafe fn setWantsExtendedDynamicRangeContent( &self, wants_extended_dynamic_range_content: bool )
pub fn minificationFilter(&self) -> Retained<NSString>
pub fn setMinificationFilter(&self, minification_filter: &NSString)
pub fn magnificationFilter(&self) -> Retained<NSString>
pub fn setMagnificationFilter(&self, magnification_filter: &NSString)
pub fn minificationFilterBias(&self) -> f32
pub fn setMinificationFilterBias(&self, minification_filter_bias: f32)
pub fn isOpaque(&self) -> bool
pub fn setOpaque(&self, opaque: bool)
pub fn display(&self)
pub fn setNeedsDisplay(&self)
pub fn setNeedsDisplayInRect(&self, r: CGRect)
pub fn needsDisplay(&self) -> bool
pub fn displayIfNeeded(&self)
pub fn needsDisplayOnBoundsChange(&self) -> bool
pub fn setNeedsDisplayOnBoundsChange( &self, needs_display_on_bounds_change: bool )
pub fn drawsAsynchronously(&self) -> bool
pub fn setDrawsAsynchronously(&self, draws_asynchronously: bool)
pub fn edgeAntialiasingMask(&self) -> CAEdgeAntialiasingMask
pub fn setEdgeAntialiasingMask( &self, edge_antialiasing_mask: CAEdgeAntialiasingMask )
pub fn allowsEdgeAntialiasing(&self) -> bool
pub fn setAllowsEdgeAntialiasing(&self, allows_edge_antialiasing: bool)
pub fn cornerRadius(&self) -> f64
pub fn setCornerRadius(&self, corner_radius: f64)
pub fn maskedCorners(&self) -> CACornerMask
pub fn setMaskedCorners(&self, masked_corners: CACornerMask)
pub fn cornerCurve(&self) -> Retained<NSString>
pub fn setCornerCurve(&self, corner_curve: &NSString)
pub fn borderWidth(&self) -> f64
pub fn setBorderWidth(&self, border_width: f64)
pub fn opacity(&self) -> f32
pub fn setOpacity(&self, opacity: f32)
pub fn allowsGroupOpacity(&self) -> bool
pub fn setAllowsGroupOpacity(&self, allows_group_opacity: bool)
pub unsafe fn compositingFilter(&self) -> Option<Retained<AnyObject>>
pub unsafe fn setCompositingFilter( &self, compositing_filter: Option<&AnyObject> )
pub unsafe fn filters(&self) -> Option<Retained<NSArray>>
pub unsafe fn setFilters(&self, filters: Option<&NSArray>)
pub unsafe fn backgroundFilters(&self) -> Option<Retained<NSArray>>
pub unsafe fn setBackgroundFilters(&self, background_filters: Option<&NSArray>)
pub fn shouldRasterize(&self) -> bool
pub fn setShouldRasterize(&self, should_rasterize: bool)
pub fn rasterizationScale(&self) -> f64
pub fn setRasterizationScale(&self, rasterization_scale: f64)
pub fn shadowOpacity(&self) -> f32
pub fn setShadowOpacity(&self, shadow_opacity: f32)
pub fn shadowOffset(&self) -> CGSize
pub fn setShadowOffset(&self, shadow_offset: CGSize)
pub fn shadowRadius(&self) -> f64
pub fn setShadowRadius(&self, shadow_radius: f64)
pub fn autoresizingMask(&self) -> CAAutoresizingMask
pub fn setAutoresizingMask(&self, autoresizing_mask: CAAutoresizingMask)
pub fn layoutManager( &self ) -> Option<Retained<ProtocolObject<dyn CALayoutManager>>>
pub fn setLayoutManager( &self, layout_manager: Option<&ProtocolObject<dyn CALayoutManager>> )
pub fn preferredFrameSize(&self) -> CGSize
pub fn setNeedsLayout(&self)
pub fn needsLayout(&self) -> bool
pub fn layoutIfNeeded(&self)
pub fn layoutSublayers(&self)
pub fn resizeSublayersWithOldSize(&self, size: CGSize)
pub fn resizeWithOldSuperlayerSize(&self, size: CGSize)
pub fn actionForKey( &self, event: &NSString ) -> Option<Retained<ProtocolObject<dyn CAAction>>>
pub fn actions( &self ) -> Option<Retained<NSDictionary<NSString, ProtocolObject<dyn CAAction>>>>
pub fn setActions( &self, actions: Option<&NSDictionary<NSString, ProtocolObject<dyn CAAction>>> )
pub fn removeAllAnimations(&self)
pub fn removeAnimationForKey(&self, key: &NSString)
pub fn animationKeys(&self) -> Option<Retained<NSArray<NSString>>>
pub fn name(&self) -> Option<Retained<NSString>>
pub fn setName(&self, name: Option<&NSString>)
pub fn delegate(&self) -> Option<Retained<ProtocolObject<dyn CALayerDelegate>>>
pub fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CALayerDelegate>> )
pub unsafe fn style(&self) -> Option<Retained<NSDictionary>>
pub unsafe fn setStyle(&self, style: Option<&NSDictionary>)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.