Struct objc2_ui_kit::UINavigationItem
source · #[repr(C)]pub struct UINavigationItem { /* private fields */ }Available on crate feature
UINavigationItem only.Implementations
pub unsafe fn initWithTitle( this: Allocated<Self>, title: &NSString ) -> Retained<Self>
pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder ) -> Option<Retained<Self>>
pub unsafe fn title(&self) -> Option<Retained<NSString>>
pub unsafe fn setTitle(&self, title: Option<&NSString>)
pub unsafe fn titleView(&self) -> Option<Retained<UIView>>
Available on crate features
UIResponder and UIView only.pub unsafe fn setTitleView(&self, title_view: Option<&UIView>)
Available on crate features
UIResponder and UIView only.pub unsafe fn prompt(&self) -> Option<Retained<NSString>>
pub unsafe fn setPrompt(&self, prompt: Option<&NSString>)
pub unsafe fn backBarButtonItem(&self) -> Option<Retained<UIBarButtonItem>>
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setBackBarButtonItem( &self, back_bar_button_item: Option<&UIBarButtonItem> )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn backButtonTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn setBackButtonTitle(&self, back_button_title: Option<&NSString>)
pub unsafe fn hidesBackButton(&self) -> bool
pub unsafe fn setHidesBackButton(&self, hides_back_button: bool)
pub unsafe fn setHidesBackButton_animated( &self, hides_back_button: bool, animated: bool )
pub unsafe fn backButtonDisplayMode( &self ) -> UINavigationItemBackButtonDisplayMode
pub unsafe fn setBackButtonDisplayMode( &self, back_button_display_mode: UINavigationItemBackButtonDisplayMode )
pub unsafe fn backAction(&self) -> Option<Retained<UIAction>>
Available on crate features
UIAction and UIMenuElement only.pub unsafe fn setBackAction(&self, back_action: Option<&UIAction>)
Available on crate features
UIAction and UIMenuElement only.pub unsafe fn titleMenuProvider( &self ) -> *mut Block<dyn Fn(NonNull<NSArray<UIMenuElement>>) -> *mut UIMenu>
Available on crate features
UIMenu and UIMenuElement and block2 only.pub unsafe fn setTitleMenuProvider( &self, title_menu_provider: Option<&Block<dyn Fn(NonNull<NSArray<UIMenuElement>>) -> *mut UIMenu>> )
Available on crate features
UIMenu and UIMenuElement and block2 only.pub unsafe fn renameDelegate( &self ) -> Option<Retained<ProtocolObject<dyn UINavigationItemRenameDelegate>>>
pub unsafe fn setRenameDelegate( &self, rename_delegate: Option<&ProtocolObject<dyn UINavigationItemRenameDelegate>> )
pub unsafe fn documentProperties( &self ) -> Option<Retained<UIDocumentProperties>>
Available on crate feature
UIDocumentProperties only.pub unsafe fn setDocumentProperties( &self, document_properties: Option<&UIDocumentProperties> )
Available on crate feature
UIDocumentProperties only.pub unsafe fn leftBarButtonItems( &self ) -> Option<Retained<NSArray<UIBarButtonItem>>>
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setLeftBarButtonItems( &self, left_bar_button_items: Option<&NSArray<UIBarButtonItem>> )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn rightBarButtonItems( &self ) -> Option<Retained<NSArray<UIBarButtonItem>>>
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setRightBarButtonItems( &self, right_bar_button_items: Option<&NSArray<UIBarButtonItem>> )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setLeftBarButtonItems_animated( &self, items: Option<&NSArray<UIBarButtonItem>>, animated: bool )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setRightBarButtonItems_animated( &self, items: Option<&NSArray<UIBarButtonItem>>, animated: bool )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn leftItemsSupplementBackButton(&self) -> bool
pub unsafe fn setLeftItemsSupplementBackButton( &self, left_items_supplement_back_button: bool )
pub unsafe fn leftBarButtonItem(&self) -> Option<Retained<UIBarButtonItem>>
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setLeftBarButtonItem( &self, left_bar_button_item: Option<&UIBarButtonItem> )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn rightBarButtonItem(&self) -> Option<Retained<UIBarButtonItem>>
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setRightBarButtonItem( &self, right_bar_button_item: Option<&UIBarButtonItem> )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setLeftBarButtonItem_animated( &self, item: Option<&UIBarButtonItem>, animated: bool )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn setRightBarButtonItem_animated( &self, item: Option<&UIBarButtonItem>, animated: bool )
Available on crate features
UIBarButtonItem and UIBarItem only.pub unsafe fn customizationIdentifier(&self) -> Option<Retained<NSString>>
pub unsafe fn setCustomizationIdentifier( &self, customization_identifier: Option<&NSString> )
pub unsafe fn leadingItemGroups( &self ) -> Retained<NSArray<UIBarButtonItemGroup>>
Available on crate feature
UIBarButtonItemGroup only.pub unsafe fn setLeadingItemGroups( &self, leading_item_groups: &NSArray<UIBarButtonItemGroup> )
Available on crate feature
UIBarButtonItemGroup only.pub unsafe fn centerItemGroups(&self) -> Retained<NSArray<UIBarButtonItemGroup>>
Available on crate feature
UIBarButtonItemGroup only.pub unsafe fn setCenterItemGroups( &self, center_item_groups: &NSArray<UIBarButtonItemGroup> )
Available on crate feature
UIBarButtonItemGroup only.pub unsafe fn trailingItemGroups( &self ) -> Retained<NSArray<UIBarButtonItemGroup>>
Available on crate feature
UIBarButtonItemGroup only.pub unsafe fn setTrailingItemGroups( &self, trailing_item_groups: &NSArray<UIBarButtonItemGroup> )
Available on crate feature
UIBarButtonItemGroup only.pub unsafe fn pinnedTrailingGroup( &self ) -> Option<Retained<UIBarButtonItemGroup>>
Available on crate feature
UIBarButtonItemGroup only.pub unsafe fn setPinnedTrailingGroup( &self, pinned_trailing_group: Option<&UIBarButtonItemGroup> )
Available on crate feature
UIBarButtonItemGroup only.pub unsafe fn additionalOverflowItems( &self ) -> Option<Retained<UIDeferredMenuElement>>
Available on crate features
UIDeferredMenuElement and UIMenuElement only.pub unsafe fn setAdditionalOverflowItems( &self, additional_overflow_items: Option<&UIDeferredMenuElement> )
Available on crate features
UIDeferredMenuElement and UIMenuElement only.pub unsafe fn overflowPresentationSource( &self ) -> Option<Retained<ProtocolObject<dyn UIPopoverPresentationControllerSourceItem>>>
Available on crate feature
UIPopoverPresentationControllerSourceItem only.pub unsafe fn largeTitleDisplayMode( &self ) -> UINavigationItemLargeTitleDisplayMode
pub unsafe fn setLargeTitleDisplayMode( &self, large_title_display_mode: UINavigationItemLargeTitleDisplayMode )
pub unsafe fn style(&self) -> UINavigationItemStyle
pub unsafe fn setStyle(&self, style: UINavigationItemStyle)
pub unsafe fn searchController(&self) -> Option<Retained<UISearchController>>
Available on crate features
UIResponder and UISearchController and UIViewController only.pub unsafe fn setSearchController( &self, search_controller: Option<&UISearchController> )
Available on crate features
UIResponder and UISearchController and UIViewController only.pub unsafe fn hidesSearchBarWhenScrolling(&self) -> bool
pub unsafe fn setHidesSearchBarWhenScrolling( &self, hides_search_bar_when_scrolling: bool )
pub unsafe fn preferredSearchBarPlacement( &self ) -> UINavigationItemSearchBarPlacement
pub unsafe fn setPreferredSearchBarPlacement( &self, preferred_search_bar_placement: UINavigationItemSearchBarPlacement )
pub unsafe fn searchBarPlacement(&self) -> UINavigationItemSearchBarPlacement
pub unsafe fn standardAppearance( &self ) -> Option<Retained<UINavigationBarAppearance>>
Available on crate features
UIBarAppearance and UINavigationBarAppearance only.pub unsafe fn setStandardAppearance( &self, standard_appearance: Option<&UINavigationBarAppearance> )
Available on crate features
UIBarAppearance and UINavigationBarAppearance only.pub unsafe fn compactAppearance( &self ) -> Option<Retained<UINavigationBarAppearance>>
Available on crate features
UIBarAppearance and UINavigationBarAppearance only.pub unsafe fn setCompactAppearance( &self, compact_appearance: Option<&UINavigationBarAppearance> )
Available on crate features
UIBarAppearance and UINavigationBarAppearance only.pub unsafe fn scrollEdgeAppearance( &self ) -> Option<Retained<UINavigationBarAppearance>>
Available on crate features
UIBarAppearance and UINavigationBarAppearance only.pub unsafe fn setScrollEdgeAppearance( &self, scroll_edge_appearance: Option<&UINavigationBarAppearance> )
Available on crate features
UIBarAppearance and UINavigationBarAppearance only.pub unsafe fn compactScrollEdgeAppearance( &self ) -> Option<Retained<UINavigationBarAppearance>>
Available on crate features
UIBarAppearance and UINavigationBarAppearance only.pub unsafe fn setCompactScrollEdgeAppearance( &self, compact_scroll_edge_appearance: Option<&UINavigationBarAppearance> )
Available on crate features
UIBarAppearance and UINavigationBarAppearance only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.