pub struct UIResponder { /* private fields */ }UIResponder only.Expand description
Implementations
Sourceimpl UIResponder
impl UIResponder
pub fn nextResponder(&self) -> Option<Retained<UIResponder>>
pub fn canBecomeFirstResponder(&self) -> bool
pub fn becomeFirstResponder(&self) -> bool
pub fn canResignFirstResponder(&self) -> bool
pub fn resignFirstResponder(&self) -> bool
pub fn isFirstResponder(&self) -> bool
pub fn touchesBegan_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent>, )
UIEvent and UITouch only.pub fn touchesMoved_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent>, )
UIEvent and UITouch only.pub fn touchesEnded_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent>, )
UIEvent and UITouch only.pub fn touchesCancelled_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent>, )
UIEvent and UITouch only.pub fn touchesEstimatedPropertiesUpdated(&self, touches: &NSSet<UITouch>)
UITouch only.pub fn pressesBegan_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent>, )
UIEvent and UIPress and UIPressesEvent only.pub fn pressesChanged_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent>, )
UIEvent and UIPress and UIPressesEvent only.pub fn pressesEnded_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent>, )
UIEvent and UIPress and UIPressesEvent only.pub fn pressesCancelled_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent>, )
UIEvent and UIPress and UIPressesEvent only.pub fn motionBegan_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent>, )
UIEvent only.pub fn motionEnded_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent>, )
UIEvent only.pub fn motionCancelled_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent>, )
UIEvent only.pub fn remoteControlReceivedWithEvent(&self, event: Option<&UIEvent>)
UIEvent only.Sourcepub unsafe fn canPerformAction_withSender(
&self,
action: Sel,
sender: Option<&AnyObject>,
) -> bool
pub unsafe fn canPerformAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> bool
Safety
actionmust be a valid selector.sendershould be of the correct type.
Sourcepub unsafe fn targetForAction_withSender(
&self,
action: Sel,
sender: Option<&AnyObject>,
) -> Option<Retained<AnyObject>>
pub unsafe fn targetForAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>
Safety
actionmust be a valid selector.sendershould be of the correct type.
pub fn buildMenuWithBuilder(&self, builder: &ProtocolObject<dyn UIMenuBuilder>)
UIMenuBuilder only.pub fn validateCommand(&self, command: &UICommand)
UICommand and UIMenuElement only.Sourcepub fn providerForDeferredMenuElement(
&self,
deferred_element: &UIDeferredMenuElement,
) -> Option<Retained<UIDeferredMenuElementProvider>>
Available on crate features UIDeferredMenuElement and UIMenuElement only.
pub fn providerForDeferredMenuElement( &self, deferred_element: &UIDeferredMenuElement, ) -> Option<Retained<UIDeferredMenuElementProvider>>
UIDeferredMenuElement and UIMenuElement only.Asks the responder for an element provider to fulfill the given focus-based deferred element.
Check the identifier of the deferred element to identify which deferred element this is.
By default, this returns nil. Return a non-nil provider to make this responder responsible for providing
elements for this fulfillment of the deferred element.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>
pub fn editingInteractionConfiguration( &self, ) -> UIEditingInteractionConfiguration
Sourceimpl UIResponder
Methods declared on superclass NSObject.
impl UIResponder
Methods declared on superclass NSObject.
Sourceimpl UIResponder
UIResponderKeyCommands.
impl UIResponder
UIResponderKeyCommands.
pub fn keyCommands(&self) -> Option<Retained<NSArray<UIKeyCommand>>>
UICommand and UIKeyCommand and UIMenuElement only.Sourceimpl UIResponder
UIResponderInputViewAdditions.
impl UIResponder
UIResponderInputViewAdditions.
pub fn inputView(&self) -> Option<Retained<UIView>>
UIView only.pub fn inputAccessoryView(&self) -> Option<Retained<UIView>>
UIView only.Sourcepub fn inputAssistantItem(&self) -> Retained<UITextInputAssistantItem>
Available on crate feature UITextInput only.
pub fn inputAssistantItem(&self) -> Retained<UITextInputAssistantItem>
UITextInput only.This method is for clients that wish to put buttons on the Shortcuts Bar, shown on top of the keyboard. You may modify the returned inputAssistantItem to add to or replace the existing items on the bar. Modifications made to the returned UITextInputAssistantItem are reflected automatically. This method should not be overridden. Goes up the responder chain.
pub fn inputViewController(&self) -> Option<Retained<UIInputViewController>>
UIInputViewController and UIViewController only.pub fn inputAccessoryViewController( &self, ) -> Option<Retained<UIInputViewController>>
UIInputViewController and UIViewController only.pub fn textInputMode(&self) -> Option<Retained<UITextInputMode>>
UITextInput only.pub fn textInputContextIdentifier(&self) -> Option<Retained<NSString>>
pub fn clearTextInputContextIdentifier( identifier: &NSString, mtm: MainThreadMarker, )
pub fn reloadInputViews(&self)
Sourceimpl UIResponder
ActivityContinuation.
impl UIResponder
ActivityContinuation.
pub fn userActivity(&self) -> Option<Retained<NSUserActivity>>
Sourcepub fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)
pub fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)
Setter for userActivity.
pub fn updateUserActivityState(&self, activity: &NSUserActivity)
pub fn restoreUserActivityState(&self, activity: &NSUserActivity)
impl UIResponder
UIPasteConfigurationSupporting.
Sourceimpl UIResponder
UICaptureTextFromCameraSupporting.
impl UIResponder
UICaptureTextFromCameraSupporting.
Sourcepub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)
pub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)
Safety
sender should be of the correct type.
Sourceimpl UIResponder
UIActivityItemsConfiguration.
impl UIResponder
UIActivityItemsConfiguration.
pub fn activityItemsConfiguration( &self, ) -> Option<Retained<ProtocolObject<dyn UIActivityItemsConfigurationReading>>>
UIActivityItemsConfigurationReading and UIResponder_UIActivityItemsConfiguration only.Sourcepub fn setActivityItemsConfiguration(
&self,
activity_items_configuration: Option<&ProtocolObject<dyn UIActivityItemsConfigurationReading>>,
)
Available on crate features UIActivityItemsConfigurationReading and UIResponder_UIActivityItemsConfiguration only.
pub fn setActivityItemsConfiguration( &self, activity_items_configuration: Option<&ProtocolObject<dyn UIActivityItemsConfigurationReading>>, )
UIActivityItemsConfigurationReading and UIResponder_UIActivityItemsConfiguration only.Setter for activityItemsConfiguration.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
this is difficult to use correctly, use Ivar::load instead.
UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Available on crate feature UIIndirectScribbleInteraction only.
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
UIIndirectScribbleInteraction only.Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for UIResponder
impl AsRef<AnyObject> for UIResponder
Sourceimpl AsRef<NSObject> for UIResponder
impl AsRef<NSObject> for UIResponder
Sourceimpl AsRef<UIResponder> for UIAccessibilityElement
Available on crate feature UIAccessibilityElement only.
impl AsRef<UIResponder> for UIAccessibilityElement
UIAccessibilityElement only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIActionSheet
Available on crate features UIActionSheet and UIView only.
impl AsRef<UIResponder> for UIActionSheet
UIActionSheet and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIActivityIndicatorView
Available on crate features UIActivityIndicatorView and UIView only.
impl AsRef<UIResponder> for UIActivityIndicatorView
UIActivityIndicatorView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIActivityViewController
Available on crate features UIActivityViewController and UIViewController only.
impl AsRef<UIResponder> for UIActivityViewController
UIActivityViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIAlertController
Available on crate features UIAlertController and UIViewController only.
impl AsRef<UIResponder> for UIAlertController
UIAlertController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIAlertView
Available on crate features UIAlertView and UIView only.
impl AsRef<UIResponder> for UIAlertView
UIAlertView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIApplication
Available on crate feature UIApplication only.
impl AsRef<UIResponder> for UIApplication
UIApplication only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIBackgroundExtensionView
Available on crate features UIBackgroundExtensionView and UIView only.
impl AsRef<UIResponder> for UIBackgroundExtensionView
UIBackgroundExtensionView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIButton
Available on crate features UIButton and UIControl and UIView only.
impl AsRef<UIResponder> for UIButton
UIButton and UIControl and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UICalendarView
Available on crate features UICalendarView and UIView only.
impl AsRef<UIResponder> for UICalendarView
UICalendarView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UICloudSharingController
Available on crate features UICloudSharingController and UIViewController only.
impl AsRef<UIResponder> for UICloudSharingController
UICloudSharingController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UICollectionReusableView
Available on crate features UICollectionViewCell and UIView only.
impl AsRef<UIResponder> for UICollectionReusableView
UICollectionViewCell and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UICollectionView
Available on crate features UICollectionView and UIScrollView and UIView only.
impl AsRef<UIResponder> for UICollectionView
UICollectionView and UIScrollView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UICollectionViewCell
Available on crate features UICollectionViewCell and UIView only.
impl AsRef<UIResponder> for UICollectionViewCell
UICollectionViewCell and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UICollectionViewController
Available on crate features UICollectionViewController and UIViewController only.
impl AsRef<UIResponder> for UICollectionViewController
UICollectionViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UICollectionViewListCell
Available on crate features UICollectionViewCell and UICollectionViewListCell and UIView only.
impl AsRef<UIResponder> for UICollectionViewListCell
UICollectionViewCell and UICollectionViewListCell and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIColorPickerViewController
Available on crate features UIColorPickerViewController and UIViewController only.
impl AsRef<UIResponder> for UIColorPickerViewController
UIColorPickerViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIColorWell
Available on crate features UIColorWell and UIControl and UIView only.
impl AsRef<UIResponder> for UIColorWell
UIColorWell and UIControl and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIControl
Available on crate features UIControl and UIView only.
impl AsRef<UIResponder> for UIControl
UIControl and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIDatePicker
Available on crate features UIControl and UIDatePicker and UIView only.
impl AsRef<UIResponder> for UIDatePicker
UIControl and UIDatePicker and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIDocumentBrowserViewController
Available on crate features UIDocumentBrowserViewController and UIViewController only.
impl AsRef<UIResponder> for UIDocumentBrowserViewController
UIDocumentBrowserViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIDocumentMenuViewController
Available on crate features UIDocumentMenuViewController and UIViewController only.
impl AsRef<UIResponder> for UIDocumentMenuViewController
UIDocumentMenuViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIDocumentPickerExtensionViewController
Available on crate features UIDocumentPickerExtensionViewController and UIViewController only.
impl AsRef<UIResponder> for UIDocumentPickerExtensionViewController
UIDocumentPickerExtensionViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIDocumentPickerViewController
Available on crate features UIDocumentPickerViewController and UIViewController only.
impl AsRef<UIResponder> for UIDocumentPickerViewController
UIDocumentPickerViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIDocumentViewController
Available on crate features UIDocumentViewController and UIViewController only.
impl AsRef<UIResponder> for UIDocumentViewController
UIDocumentViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIEventAttributionView
Available on crate features UIEventAttributionView and UIView only.
impl AsRef<UIResponder> for UIEventAttributionView
UIEventAttributionView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIFontPickerViewController
Available on crate features UIFontPickerViewController and UIViewController only.
impl AsRef<UIResponder> for UIFontPickerViewController
UIFontPickerViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIImagePickerController
Available on crate features UIImagePickerController and UINavigationController and UIViewController only.
impl AsRef<UIResponder> for UIImagePickerController
UIImagePickerController and UINavigationController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIImageView
Available on crate features UIImageView and UIView only.
impl AsRef<UIResponder> for UIImageView
UIImageView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIInputView
Available on crate features UIInputView and UIView only.
impl AsRef<UIResponder> for UIInputView
UIInputView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIInputViewController
Available on crate features UIInputViewController and UIViewController only.
impl AsRef<UIResponder> for UIInputViewController
UIInputViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UILabel
Available on crate features UILabel and UIView only.
impl AsRef<UIResponder> for UILabel
UILabel and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIListContentView
Available on crate features UIListContentConfiguration and UIView only.
impl AsRef<UIResponder> for UIListContentView
UIListContentConfiguration and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIPageControl
Available on crate features UIControl and UIPageControl and UIView only.
impl AsRef<UIResponder> for UIPageControl
UIControl and UIPageControl and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIPageViewController
Available on crate features UIPageViewController and UIViewController only.
impl AsRef<UIResponder> for UIPageViewController
UIPageViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIPasteControl
Available on crate features UIControl and UIPasteControl and UIView only.
impl AsRef<UIResponder> for UIPasteControl
UIControl and UIPasteControl and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIPickerView
Available on crate features UIPickerView and UIView only.
impl AsRef<UIResponder> for UIPickerView
UIPickerView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIPopoverBackgroundView
Available on crate features UIPopoverBackgroundView and UIView only.
impl AsRef<UIResponder> for UIPopoverBackgroundView
UIPopoverBackgroundView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIProgressView
Available on crate features UIProgressView and UIView only.
impl AsRef<UIResponder> for UIProgressView
UIProgressView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIReferenceLibraryViewController
Available on crate features UIReferenceLibraryViewController and UIViewController only.
impl AsRef<UIResponder> for UIReferenceLibraryViewController
UIReferenceLibraryViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIRefreshControl
Available on crate features UIControl and UIRefreshControl and UIView only.
impl AsRef<UIResponder> for UIRefreshControl
UIControl and UIRefreshControl and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIResponder
impl AsRef<UIResponder> for UIResponder
Sourceimpl AsRef<UIResponder> for UIScene
Available on crate feature UIScene only.
impl AsRef<UIResponder> for UIScene
UIScene only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIScrollView
Available on crate features UIScrollView and UIView only.
impl AsRef<UIResponder> for UIScrollView
UIScrollView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UISearchBar
Available on crate features UISearchBar and UIView only.
impl AsRef<UIResponder> for UISearchBar
UISearchBar and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UISearchContainerViewController
Available on crate features UISearchContainerViewController and UIViewController only.
impl AsRef<UIResponder> for UISearchContainerViewController
UISearchContainerViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UISearchController
Available on crate features UISearchController and UIViewController only.
impl AsRef<UIResponder> for UISearchController
UISearchController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UISearchTextField
Available on crate features UIControl and UISearchTextField and UITextField and UIView only.
impl AsRef<UIResponder> for UISearchTextField
UIControl and UISearchTextField and UITextField and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UISegmentedControl
Available on crate features UIControl and UISegmentedControl and UIView only.
impl AsRef<UIResponder> for UISegmentedControl
UIControl and UISegmentedControl and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UISlider
Available on crate features UIControl and UISlider and UIView only.
impl AsRef<UIResponder> for UISlider
UIControl and UISlider and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UISplitViewController
Available on crate features UISplitViewController and UIViewController only.
impl AsRef<UIResponder> for UISplitViewController
UISplitViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIStackView
Available on crate features UIStackView and UIView only.
impl AsRef<UIResponder> for UIStackView
UIStackView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIStandardTextCursorView
Available on crate features UIStandardTextCursorView and UIView only.
impl AsRef<UIResponder> for UIStandardTextCursorView
UIStandardTextCursorView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIStepper
Available on crate features UIControl and UIStepper and UIView only.
impl AsRef<UIResponder> for UIStepper
UIControl and UIStepper and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UISwitch
Available on crate features UIControl and UISwitch and UIView only.
impl AsRef<UIResponder> for UISwitch
UIControl and UISwitch and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UITabBar
Available on crate features UITabBar and UIView only.
impl AsRef<UIResponder> for UITabBar
UITabBar and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UITabBarController
Available on crate features UITabBarController and UIViewController only.
impl AsRef<UIResponder> for UITabBarController
UITabBarController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UITableView
Available on crate features UIScrollView and UITableView and UIView only.
impl AsRef<UIResponder> for UITableView
UIScrollView and UITableView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UITableViewCell
Available on crate features UITableViewCell and UIView only.
impl AsRef<UIResponder> for UITableViewCell
UITableViewCell and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UITableViewController
Available on crate features UITableViewController and UIViewController only.
impl AsRef<UIResponder> for UITableViewController
UITableViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UITextField
Available on crate features UIControl and UITextField and UIView only.
impl AsRef<UIResponder> for UITextField
UIControl and UITextField and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UITextFormattingViewController
Available on crate features UITextFormattingViewController and UIViewController only.
impl AsRef<UIResponder> for UITextFormattingViewController
UITextFormattingViewController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UITextView
Available on crate features UIScrollView and UITextView and UIView only.
impl AsRef<UIResponder> for UITextView
UIScrollView and UITextView and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIToolbar
Available on crate features UIToolbar and UIView only.
impl AsRef<UIResponder> for UIToolbar
UIToolbar and UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIVideoEditorController
Available on crate features UINavigationController and UIVideoEditorController and UIViewController only.
impl AsRef<UIResponder> for UIVideoEditorController
UINavigationController and UIVideoEditorController and UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIView
Available on crate feature UIView only.
impl AsRef<UIResponder> for UIView
UIView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIViewController
Available on crate feature UIViewController only.
impl AsRef<UIResponder> for UIViewController
UIViewController only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIVisualEffectView
Available on crate features UIView and UIVisualEffectView only.
impl AsRef<UIResponder> for UIVisualEffectView
UIView and UIVisualEffectView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIWebView
Available on crate features UIView and UIWebView only.
impl AsRef<UIResponder> for UIWebView
UIView and UIWebView only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIWindow
Available on crate features UIView and UIWindow only.
impl AsRef<UIResponder> for UIWindow
UIView and UIWindow only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIResponder> for UIWindowScene
Available on crate features UIScene and UIWindowScene only.
impl AsRef<UIResponder> for UIWindowScene
UIScene and UIWindowScene only.Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl Borrow<AnyObject> for UIResponder
impl Borrow<AnyObject> for UIResponder
Sourceimpl Borrow<NSObject> for UIResponder
impl Borrow<NSObject> for UIResponder
Sourceimpl Borrow<UIResponder> for UIAccessibilityElement
Available on crate feature UIAccessibilityElement only.
impl Borrow<UIResponder> for UIAccessibilityElement
UIAccessibilityElement only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIActionSheet
Available on crate features UIActionSheet and UIView only.
impl Borrow<UIResponder> for UIActionSheet
UIActionSheet and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIActivityIndicatorView
Available on crate features UIActivityIndicatorView and UIView only.
impl Borrow<UIResponder> for UIActivityIndicatorView
UIActivityIndicatorView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIActivityViewController
Available on crate features UIActivityViewController and UIViewController only.
impl Borrow<UIResponder> for UIActivityViewController
UIActivityViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIAlertController
Available on crate features UIAlertController and UIViewController only.
impl Borrow<UIResponder> for UIAlertController
UIAlertController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIAlertView
Available on crate features UIAlertView and UIView only.
impl Borrow<UIResponder> for UIAlertView
UIAlertView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIApplication
Available on crate feature UIApplication only.
impl Borrow<UIResponder> for UIApplication
UIApplication only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIBackgroundExtensionView
Available on crate features UIBackgroundExtensionView and UIView only.
impl Borrow<UIResponder> for UIBackgroundExtensionView
UIBackgroundExtensionView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIButton
Available on crate features UIButton and UIControl and UIView only.
impl Borrow<UIResponder> for UIButton
UIButton and UIControl and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UICalendarView
Available on crate features UICalendarView and UIView only.
impl Borrow<UIResponder> for UICalendarView
UICalendarView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UICloudSharingController
Available on crate features UICloudSharingController and UIViewController only.
impl Borrow<UIResponder> for UICloudSharingController
UICloudSharingController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UICollectionReusableView
Available on crate features UICollectionViewCell and UIView only.
impl Borrow<UIResponder> for UICollectionReusableView
UICollectionViewCell and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UICollectionView
Available on crate features UICollectionView and UIScrollView and UIView only.
impl Borrow<UIResponder> for UICollectionView
UICollectionView and UIScrollView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UICollectionViewCell
Available on crate features UICollectionViewCell and UIView only.
impl Borrow<UIResponder> for UICollectionViewCell
UICollectionViewCell and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UICollectionViewController
Available on crate features UICollectionViewController and UIViewController only.
impl Borrow<UIResponder> for UICollectionViewController
UICollectionViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UICollectionViewListCell
Available on crate features UICollectionViewCell and UICollectionViewListCell and UIView only.
impl Borrow<UIResponder> for UICollectionViewListCell
UICollectionViewCell and UICollectionViewListCell and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIColorPickerViewController
Available on crate features UIColorPickerViewController and UIViewController only.
impl Borrow<UIResponder> for UIColorPickerViewController
UIColorPickerViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIColorWell
Available on crate features UIColorWell and UIControl and UIView only.
impl Borrow<UIResponder> for UIColorWell
UIColorWell and UIControl and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIControl
Available on crate features UIControl and UIView only.
impl Borrow<UIResponder> for UIControl
UIControl and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIDatePicker
Available on crate features UIControl and UIDatePicker and UIView only.
impl Borrow<UIResponder> for UIDatePicker
UIControl and UIDatePicker and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIDocumentBrowserViewController
Available on crate features UIDocumentBrowserViewController and UIViewController only.
impl Borrow<UIResponder> for UIDocumentBrowserViewController
UIDocumentBrowserViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIDocumentMenuViewController
Available on crate features UIDocumentMenuViewController and UIViewController only.
impl Borrow<UIResponder> for UIDocumentMenuViewController
UIDocumentMenuViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIDocumentPickerExtensionViewController
Available on crate features UIDocumentPickerExtensionViewController and UIViewController only.
impl Borrow<UIResponder> for UIDocumentPickerExtensionViewController
UIDocumentPickerExtensionViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIDocumentPickerViewController
Available on crate features UIDocumentPickerViewController and UIViewController only.
impl Borrow<UIResponder> for UIDocumentPickerViewController
UIDocumentPickerViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIDocumentViewController
Available on crate features UIDocumentViewController and UIViewController only.
impl Borrow<UIResponder> for UIDocumentViewController
UIDocumentViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIEventAttributionView
Available on crate features UIEventAttributionView and UIView only.
impl Borrow<UIResponder> for UIEventAttributionView
UIEventAttributionView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIFontPickerViewController
Available on crate features UIFontPickerViewController and UIViewController only.
impl Borrow<UIResponder> for UIFontPickerViewController
UIFontPickerViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIImagePickerController
Available on crate features UIImagePickerController and UINavigationController and UIViewController only.
impl Borrow<UIResponder> for UIImagePickerController
UIImagePickerController and UINavigationController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIImageView
Available on crate features UIImageView and UIView only.
impl Borrow<UIResponder> for UIImageView
UIImageView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIInputView
Available on crate features UIInputView and UIView only.
impl Borrow<UIResponder> for UIInputView
UIInputView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIInputViewController
Available on crate features UIInputViewController and UIViewController only.
impl Borrow<UIResponder> for UIInputViewController
UIInputViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UILabel
Available on crate features UILabel and UIView only.
impl Borrow<UIResponder> for UILabel
UILabel and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIListContentView
Available on crate features UIListContentConfiguration and UIView only.
impl Borrow<UIResponder> for UIListContentView
UIListContentConfiguration and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIPageControl
Available on crate features UIControl and UIPageControl and UIView only.
impl Borrow<UIResponder> for UIPageControl
UIControl and UIPageControl and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIPageViewController
Available on crate features UIPageViewController and UIViewController only.
impl Borrow<UIResponder> for UIPageViewController
UIPageViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIPasteControl
Available on crate features UIControl and UIPasteControl and UIView only.
impl Borrow<UIResponder> for UIPasteControl
UIControl and UIPasteControl and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIPickerView
Available on crate features UIPickerView and UIView only.
impl Borrow<UIResponder> for UIPickerView
UIPickerView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIPopoverBackgroundView
Available on crate features UIPopoverBackgroundView and UIView only.
impl Borrow<UIResponder> for UIPopoverBackgroundView
UIPopoverBackgroundView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIProgressView
Available on crate features UIProgressView and UIView only.
impl Borrow<UIResponder> for UIProgressView
UIProgressView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIReferenceLibraryViewController
Available on crate features UIReferenceLibraryViewController and UIViewController only.
impl Borrow<UIResponder> for UIReferenceLibraryViewController
UIReferenceLibraryViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIRefreshControl
Available on crate features UIControl and UIRefreshControl and UIView only.
impl Borrow<UIResponder> for UIRefreshControl
UIControl and UIRefreshControl and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIScene
Available on crate feature UIScene only.
impl Borrow<UIResponder> for UIScene
UIScene only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIScrollView
Available on crate features UIScrollView and UIView only.
impl Borrow<UIResponder> for UIScrollView
UIScrollView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UISearchBar
Available on crate features UISearchBar and UIView only.
impl Borrow<UIResponder> for UISearchBar
UISearchBar and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UISearchContainerViewController
Available on crate features UISearchContainerViewController and UIViewController only.
impl Borrow<UIResponder> for UISearchContainerViewController
UISearchContainerViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UISearchController
Available on crate features UISearchController and UIViewController only.
impl Borrow<UIResponder> for UISearchController
UISearchController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UISearchTextField
Available on crate features UIControl and UISearchTextField and UITextField and UIView only.
impl Borrow<UIResponder> for UISearchTextField
UIControl and UISearchTextField and UITextField and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UISegmentedControl
Available on crate features UIControl and UISegmentedControl and UIView only.
impl Borrow<UIResponder> for UISegmentedControl
UIControl and UISegmentedControl and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UISlider
Available on crate features UIControl and UISlider and UIView only.
impl Borrow<UIResponder> for UISlider
UIControl and UISlider and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UISplitViewController
Available on crate features UISplitViewController and UIViewController only.
impl Borrow<UIResponder> for UISplitViewController
UISplitViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIStackView
Available on crate features UIStackView and UIView only.
impl Borrow<UIResponder> for UIStackView
UIStackView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIStandardTextCursorView
Available on crate features UIStandardTextCursorView and UIView only.
impl Borrow<UIResponder> for UIStandardTextCursorView
UIStandardTextCursorView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIStepper
Available on crate features UIControl and UIStepper and UIView only.
impl Borrow<UIResponder> for UIStepper
UIControl and UIStepper and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UISwitch
Available on crate features UIControl and UISwitch and UIView only.
impl Borrow<UIResponder> for UISwitch
UIControl and UISwitch and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UITabBar
Available on crate features UITabBar and UIView only.
impl Borrow<UIResponder> for UITabBar
UITabBar and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UITabBarController
Available on crate features UITabBarController and UIViewController only.
impl Borrow<UIResponder> for UITabBarController
UITabBarController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UITableView
Available on crate features UIScrollView and UITableView and UIView only.
impl Borrow<UIResponder> for UITableView
UIScrollView and UITableView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UITableViewCell
Available on crate features UITableViewCell and UIView only.
impl Borrow<UIResponder> for UITableViewCell
UITableViewCell and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UITableViewController
Available on crate features UITableViewController and UIViewController only.
impl Borrow<UIResponder> for UITableViewController
UITableViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UITextField
Available on crate features UIControl and UITextField and UIView only.
impl Borrow<UIResponder> for UITextField
UIControl and UITextField and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UITextFormattingViewController
Available on crate features UITextFormattingViewController and UIViewController only.
impl Borrow<UIResponder> for UITextFormattingViewController
UITextFormattingViewController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UITextView
Available on crate features UIScrollView and UITextView and UIView only.
impl Borrow<UIResponder> for UITextView
UIScrollView and UITextView and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIToolbar
Available on crate features UIToolbar and UIView only.
impl Borrow<UIResponder> for UIToolbar
UIToolbar and UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIVideoEditorController
Available on crate features UINavigationController and UIVideoEditorController and UIViewController only.
impl Borrow<UIResponder> for UIVideoEditorController
UINavigationController and UIVideoEditorController and UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIView
Available on crate feature UIView only.
impl Borrow<UIResponder> for UIView
UIView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIViewController
Available on crate feature UIViewController only.
impl Borrow<UIResponder> for UIViewController
UIViewController only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIVisualEffectView
Available on crate features UIView and UIVisualEffectView only.
impl Borrow<UIResponder> for UIVisualEffectView
UIView and UIVisualEffectView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIWebView
Available on crate features UIView and UIWebView only.
impl Borrow<UIResponder> for UIWebView
UIView and UIWebView only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIWindow
Available on crate features UIView and UIWindow only.
impl Borrow<UIResponder> for UIWindow
UIView and UIWindow only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for UIWindowScene
Available on crate features UIScene and UIWindowScene only.
impl Borrow<UIResponder> for UIWindowScene
UIScene and UIWindowScene only.Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl ClassType for UIResponder
impl ClassType for UIResponder
Sourceconst NAME: &'static str = "UIResponder"
const NAME: &'static str = "UIResponder"
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Debug for UIResponder
impl Debug for UIResponder
Sourceimpl Deref for UIResponder
impl Deref for UIResponder
Sourceimpl Hash for UIResponder
impl Hash for UIResponder
Sourceimpl Message for UIResponder
impl Message for UIResponder
Sourceimpl NSObjectProtocol for UIResponder
impl NSObjectProtocol for UIResponder
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
use isKindOfClass directly, or cast your objects with AnyObject::downcast_ref
Sourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl PartialEq for UIResponder
impl PartialEq for UIResponder
Sourceimpl RefEncode for UIResponder
impl RefEncode for UIResponder
Sourceconst ENCODING_REF: Encoding = <NSObject as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <NSObject as ::objc2::RefEncode>::ENCODING_REF
Sourceimpl UIActivityItemsConfigurationProviding for UIResponder
Available on crate feature UIResponder_UIActivityItemsConfiguration only.
impl UIActivityItemsConfigurationProviding for UIResponder
UIResponder_UIActivityItemsConfiguration only.Sourcefn activityItemsConfiguration(
&self,
mtm: MainThreadMarker,
) -> Option<Retained<ProtocolObject<dyn UIActivityItemsConfigurationReading>>>
fn activityItemsConfiguration( &self, mtm: MainThreadMarker, ) -> Option<Retained<ProtocolObject<dyn UIActivityItemsConfigurationReading>>>
UIActivityItemsConfigurationReading only.Sourceimpl UIPasteConfigurationSupporting for UIResponder
impl UIPasteConfigurationSupporting for UIResponder
Sourcefn pasteConfiguration(&self) -> Option<Retained<UIPasteConfiguration>>
fn pasteConfiguration(&self) -> Option<Retained<UIPasteConfiguration>>
UIPasteConfiguration and UIPasteConfigurationSupporting only.Sourcefn setPasteConfiguration(
&self,
paste_configuration: Option<&UIPasteConfiguration>,
)
fn setPasteConfiguration( &self, paste_configuration: Option<&UIPasteConfiguration>, )
UIPasteConfiguration and UIPasteConfigurationSupporting only.pasteConfiguration. Read moreSourcefn pasteItemProviders(&self, item_providers: &NSArray<NSItemProvider>)
fn pasteItemProviders(&self, item_providers: &NSArray<NSItemProvider>)
UIPasteConfigurationSupporting only.Sourcefn canPasteItemProviders(
&self,
item_providers: &NSArray<NSItemProvider>,
) -> bool
fn canPasteItemProviders( &self, item_providers: &NSArray<NSItemProvider>, ) -> bool
UIPasteConfigurationSupporting only.Sourceimpl UIResponderStandardEditActions for UIResponder
impl UIResponderStandardEditActions for UIResponder
Sourceunsafe fn makeTextWritingDirectionLeftToRight(&self, sender: Option<&AnyObject>)
unsafe fn makeTextWritingDirectionLeftToRight(&self, sender: Option<&AnyObject>)
Sourceunsafe fn makeTextWritingDirectionRightToLeft(&self, sender: Option<&AnyObject>)
unsafe fn makeTextWritingDirectionRightToLeft(&self, sender: Option<&AnyObject>)
Sourceunsafe fn updateTextAttributesWithConversionHandler(
&self,
conversion_handler: UITextAttributesConversionHandler,
)
unsafe fn updateTextAttributesWithConversionHandler( &self, conversion_handler: UITextAttributesConversionHandler, )
block2 only.Sourceimpl UIUserActivityRestoring for UIResponder
impl UIUserActivityRestoring for UIResponder
Sourcefn restoreUserActivityState(&self, user_activity: &NSUserActivity)
fn restoreUserActivityState(&self, user_activity: &NSUserActivity)
UIUserActivity only.impl DowncastTarget for UIResponder
impl Eq for UIResponder