Struct objc2_ui_kit::UIResponder
source · #[repr(C)]pub struct UIResponder { /* private fields */ }Available on crate feature
UIResponder only.Implementations
sourceimpl UIResponder
impl UIResponder
pub unsafe fn nextResponder(&self) -> Option<Retained<UIResponder>>
pub unsafe fn canBecomeFirstResponder(&self) -> bool
pub unsafe fn becomeFirstResponder(&self) -> bool
pub unsafe fn canResignFirstResponder(&self) -> bool
pub unsafe fn resignFirstResponder(&self) -> bool
pub unsafe fn isFirstResponder(&self) -> bool
pub unsafe fn touchesBegan_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )
Available on crate features
UIEvent and UITouch only.pub unsafe fn touchesMoved_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )
Available on crate features
UIEvent and UITouch only.pub unsafe fn touchesEnded_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )
Available on crate features
UIEvent and UITouch only.pub unsafe fn touchesCancelled_withEvent( &self, touches: &NSSet<UITouch>, event: Option<&UIEvent> )
Available on crate features
UIEvent and UITouch only.pub unsafe fn touchesEstimatedPropertiesUpdated(&self, touches: &NSSet<UITouch>)
Available on crate feature
UITouch only.pub unsafe fn pressesBegan_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )
Available on crate features
UIEvent and UIPress and UIPressesEvent only.pub unsafe fn pressesChanged_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )
Available on crate features
UIEvent and UIPress and UIPressesEvent only.pub unsafe fn pressesEnded_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )
Available on crate features
UIEvent and UIPress and UIPressesEvent only.pub unsafe fn pressesCancelled_withEvent( &self, presses: &NSSet<UIPress>, event: Option<&UIPressesEvent> )
Available on crate features
UIEvent and UIPress and UIPressesEvent only.pub unsafe fn motionBegan_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )
Available on crate feature
UIEvent only.pub unsafe fn motionEnded_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )
Available on crate feature
UIEvent only.pub unsafe fn motionCancelled_withEvent( &self, motion: UIEventSubtype, event: Option<&UIEvent> )
Available on crate feature
UIEvent only.pub unsafe fn remoteControlReceivedWithEvent(&self, event: Option<&UIEvent>)
Available on crate feature
UIEvent only.pub unsafe fn canPerformAction_withSender( &self, action: Sel, sender: Option<&AnyObject> ) -> bool
pub unsafe fn targetForAction_withSender( &self, action: Sel, sender: Option<&AnyObject> ) -> Option<Retained<AnyObject>>
pub unsafe fn buildMenuWithBuilder( &self, builder: &ProtocolObject<dyn UIMenuBuilder> )
Available on crate feature
UIMenuBuilder only.pub unsafe fn validateCommand(&self, command: &UICommand)
Available on crate features
UICommand and UIMenuElement only.pub unsafe fn undoManager(&self) -> Option<Retained<NSUndoManager>>
pub unsafe fn editingInteractionConfiguration( &self ) -> UIEditingInteractionConfiguration
sourceimpl UIResponder
impl UIResponder
Methods declared on superclass NSObject
sourceimpl UIResponder
impl UIResponder
UIResponderKeyCommands
pub unsafe fn keyCommands(&self) -> Option<Retained<NSArray<UIKeyCommand>>>
Available on crate features
UICommand and UIKeyCommand and UIMenuElement only.sourceimpl UIResponder
impl UIResponder
UIResponderInputViewAdditions
pub unsafe fn inputView(&self) -> Option<Retained<UIView>>
Available on crate feature
UIView only.pub unsafe fn inputAccessoryView(&self) -> Option<Retained<UIView>>
Available on crate feature
UIView only.pub unsafe fn inputAssistantItem(&self) -> Retained<UITextInputAssistantItem>
Available on crate feature
UITextInput only.pub unsafe fn inputViewController( &self ) -> Option<Retained<UIInputViewController>>
Available on crate features
UIInputViewController and UIViewController only.pub unsafe fn inputAccessoryViewController( &self ) -> Option<Retained<UIInputViewController>>
Available on crate features
UIInputViewController and UIViewController only.pub unsafe fn textInputMode(&self) -> Option<Retained<UITextInputMode>>
Available on crate feature
UITextInput only.pub unsafe fn textInputContextIdentifier(&self) -> Option<Retained<NSString>>
pub unsafe fn clearTextInputContextIdentifier( identifier: &NSString, mtm: MainThreadMarker )
pub unsafe fn reloadInputViews(&self)
sourceimpl UIResponder
impl UIResponder
ActivityContinuation
pub unsafe fn userActivity(&self) -> Option<Retained<NSUserActivity>>
pub unsafe fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)
pub unsafe fn updateUserActivityState(&self, activity: &NSUserActivity)
pub unsafe fn restoreUserActivityState(&self, activity: &NSUserActivity)
impl UIResponder
This impl block contains no items.
UIPasteConfigurationSupporting
sourceimpl UIResponder
impl UIResponder
UICaptureTextFromCameraSupporting
pub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)
sourceimpl UIResponder
impl UIResponder
UIActivityItemsConfiguration
pub unsafe fn activityItemsConfiguration( &self ) -> Option<Retained<ProtocolObject<dyn UIActivityItemsConfigurationReading>>>
Available on crate features
UIResponder_UIActivityItemsConfiguration and UIActivityItemsConfigurationReading only.pub unsafe fn setActivityItemsConfiguration( &self, activity_items_configuration: Option<&ProtocolObject<dyn UIActivityItemsConfigurationReading>> )
Available on crate features
UIResponder_UIActivityItemsConfiguration and UIActivityItemsConfigurationReading only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
Available on crate feature UIIndirectScribbleInteraction only.
pub fn class(&self) -> &'static AnyClass
UIIndirectScribbleInteraction only.Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.UIIndirectScribbleInteraction only.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.Available on crate feature UIIndirectScribbleInteraction only.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.UIIndirectScribbleInteraction only.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.