pub unsafe trait UICalendarSelectionMultiDateDelegate: NSObjectProtocol + MainThreadOnly {
// Provided methods
fn multiDateSelection_didSelectDate(
&self,
selection: &UICalendarSelectionMultiDate,
date_components: &NSDateComponents,
)
where Self: Sized + Message { ... }
fn multiDateSelection_didDeselectDate(
&self,
selection: &UICalendarSelectionMultiDate,
date_components: &NSDateComponents,
)
where Self: Sized + Message { ... }
fn multiDateSelection_canSelectDate(
&self,
selection: &UICalendarSelectionMultiDate,
date_components: &NSDateComponents,
) -> bool
where Self: Sized + Message { ... }
fn multiDateSelection_canDeselectDate(
&self,
selection: &UICalendarSelectionMultiDate,
date_components: &NSDateComponents,
) -> bool
where Self: Sized + Message { ... }
}UICalendarSelectionMultiDate only.Expand description
Provided Methods
Sourcefn multiDateSelection_didSelectDate(
&self,
selection: &UICalendarSelectionMultiDate,
date_components: &NSDateComponents,
)
Available on crate feature UICalendarSelection only.
fn multiDateSelection_didSelectDate( &self, selection: &UICalendarSelectionMultiDate, date_components: &NSDateComponents, )
UICalendarSelection only.Called after the user selects a date in the calendar view.
Parameter selection: The
UICalendarSelectionMultiDate
Parameter dateComponents: The date that was selected by the user.
Sourcefn multiDateSelection_didDeselectDate(
&self,
selection: &UICalendarSelectionMultiDate,
date_components: &NSDateComponents,
)
Available on crate feature UICalendarSelection only.
fn multiDateSelection_didDeselectDate( &self, selection: &UICalendarSelectionMultiDate, date_components: &NSDateComponents, )
UICalendarSelection only.Called after the user removes selection from one of hte selected dates the calendar view.
Parameter selection: The
UICalendarSelectionMultiDate
Parameter dateComponents: The date that was deselected by the user.
Sourcefn multiDateSelection_canSelectDate(
&self,
selection: &UICalendarSelectionMultiDate,
date_components: &NSDateComponents,
) -> bool
Available on crate feature UICalendarSelection only.
fn multiDateSelection_canSelectDate( &self, selection: &UICalendarSelectionMultiDate, date_components: &NSDateComponents, ) -> bool
UICalendarSelection only.Determines if a date is selectable. Dates that are not selectable will be disabled in the calendar view.
Parameter selection: The
UICalendarSelectionMultiDate
Parameter dateComponents: The date to be checked by selection.
Returns: YES if the date can be selected, NO otherwise.
Sourcefn multiDateSelection_canDeselectDate(
&self,
selection: &UICalendarSelectionMultiDate,
date_components: &NSDateComponents,
) -> bool
Available on crate feature UICalendarSelection only.
fn multiDateSelection_canDeselectDate( &self, selection: &UICalendarSelectionMultiDate, date_components: &NSDateComponents, ) -> bool
UICalendarSelection only.Determines if a date can be deselected.
Parameter selection: The
UICalendarSelectionMultiDate
Parameter dateComponents: The date to be checked by selection.
Returns: YES if the date can be deselected, NO otherwise.