pub unsafe trait UICalendarSelectionSingleDateDelegate: NSObjectProtocol + MainThreadOnly {
// Provided methods
fn dateSelection_didSelectDate(
&self,
selection: &UICalendarSelectionSingleDate,
date_components: Option<&NSDateComponents>,
)
where Self: Sized + Message { ... }
fn dateSelection_canSelectDate(
&self,
selection: &UICalendarSelectionSingleDate,
date_components: Option<&NSDateComponents>,
) -> bool
where Self: Sized + Message { ... }
}Available on crate feature
UICalendarSelectionSingleDate only.Expand description
Provided Methods
Sourcefn dateSelection_didSelectDate(
&self,
selection: &UICalendarSelectionSingleDate,
date_components: Option<&NSDateComponents>,
)
Available on crate feature UICalendarSelection only.
fn dateSelection_didSelectDate( &self, selection: &UICalendarSelectionSingleDate, date_components: Option<&NSDateComponents>, )
UICalendarSelection only.Called after the user selects a date in the calendar view.
Parameter selection: The
UICalendarSelectionMultiDate
Parameter dateComponents: The date that was selected by the user.
dateComponentscan be
nilwhen the selected date is deselected by the user.
Sourcefn dateSelection_canSelectDate(
&self,
selection: &UICalendarSelectionSingleDate,
date_components: Option<&NSDateComponents>,
) -> bool
Available on crate feature UICalendarSelection only.
fn dateSelection_canSelectDate( &self, selection: &UICalendarSelectionSingleDate, date_components: Option<&NSDateComponents>, ) -> bool
UICalendarSelection only.Determines if a date is selectable. Dates that are not selectable will be disabled in the calendar view.
By default,
dateSelection:canSelectDate:returns YES if dateComponents is non-nil.
Parameter selection: The
UICalendarSelectionMultiDate
Parameter dateComponents: The date to be checked by selection; a
nildate represents a deselected date.
Returns: YES if the date can be selected, NO otherwise.