pub unsafe trait UICalendarViewDelegate: NSObjectProtocol + MainThreadOnly {
// Provided methods
fn calendarView_decorationForDateComponents(
&self,
calendar_view: &UICalendarView,
date_components: &NSDateComponents,
) -> Option<Retained<UICalendarViewDecoration>>
where Self: Sized + Message { ... }
fn calendarView_didChangeVisibleDateComponentsFrom(
&self,
calendar_view: &UICalendarView,
previous_date_components: &NSDateComponents,
)
where Self: Sized + Message { ... }
}Available on crate feature
UICalendarView only.Expand description
Provided Methods
Sourcefn calendarView_decorationForDateComponents(
&self,
calendar_view: &UICalendarView,
date_components: &NSDateComponents,
) -> Option<Retained<UICalendarViewDecoration>>
Available on crate features UICalendarViewDecoration and UIResponder and UIView only.
fn calendarView_decorationForDateComponents( &self, calendar_view: &UICalendarView, date_components: &NSDateComponents, ) -> Option<Retained<UICalendarViewDecoration>>
UICalendarViewDecoration and UIResponder and UIView only.Called when the calendar view is preparing decorations.
Parameter calendarView: The
UICalendarView
Parameter dateComponents: The date for which the decoration is prepared for.
Returns: A
UICalendarViewDecorationto annotate the specific date. Return
nilfor no decoration.
Sourcefn calendarView_didChangeVisibleDateComponentsFrom(
&self,
calendar_view: &UICalendarView,
previous_date_components: &NSDateComponents,
)
Available on crate features UIResponder and UIView only.
fn calendarView_didChangeVisibleDateComponentsFrom( &self, calendar_view: &UICalendarView, previous_date_components: &NSDateComponents, )
UIResponder and UIView only.Called when the visible date has changed from
previousDateComponentsfrom user interaction.
Parameter calendarView: The
UICalendarView
Parameter previousDateComponents: The previous date components before the visible date components changed.