pub unsafe trait UICollectionViewDataSource: NSObjectProtocol + MainThreadOnly {
// Provided methods
fn collectionView_numberOfItemsInSection(
&self,
collection_view: &UICollectionView,
section: NSInteger,
) -> NSInteger
where Self: Sized + Message { ... }
fn collectionView_cellForItemAtIndexPath(
&self,
collection_view: &UICollectionView,
index_path: &NSIndexPath,
) -> Retained<UICollectionViewCell>
where Self: Sized + Message { ... }
fn numberOfSectionsInCollectionView(
&self,
collection_view: &UICollectionView,
) -> NSInteger
where Self: Sized + Message { ... }
fn collectionView_viewForSupplementaryElementOfKind_atIndexPath(
&self,
collection_view: &UICollectionView,
kind: &NSString,
index_path: &NSIndexPath,
) -> Retained<UICollectionReusableView>
where Self: Sized + Message { ... }
fn collectionView_canMoveItemAtIndexPath(
&self,
collection_view: &UICollectionView,
index_path: &NSIndexPath,
) -> bool
where Self: Sized + Message { ... }
fn collectionView_moveItemAtIndexPath_toIndexPath(
&self,
collection_view: &UICollectionView,
source_index_path: &NSIndexPath,
destination_index_path: &NSIndexPath,
)
where Self: Sized + Message { ... }
fn indexTitlesForCollectionView(
&self,
collection_view: &UICollectionView,
) -> Option<Retained<NSArray<NSString>>>
where Self: Sized + Message { ... }
fn collectionView_indexPathForIndexTitle_atIndex(
&self,
collection_view: &UICollectionView,
title: &NSString,
index: NSInteger,
) -> Retained<NSIndexPath>
where Self: Sized + Message { ... }
}Available on crate feature
UICollectionView only.Expand description
Provided Methods
fn collectionView_numberOfItemsInSection( &self, collection_view: &UICollectionView, section: NSInteger, ) -> NSInteger
Available on crate features
UIResponder and UIScrollView and UIView only.fn collectionView_cellForItemAtIndexPath( &self, collection_view: &UICollectionView, index_path: &NSIndexPath, ) -> Retained<UICollectionViewCell>
Available on crate features
UICollectionViewCell and UIResponder and UIScrollView and UIView only.fn numberOfSectionsInCollectionView( &self, collection_view: &UICollectionView, ) -> NSInteger
Available on crate features
UIResponder and UIScrollView and UIView only.fn collectionView_viewForSupplementaryElementOfKind_atIndexPath( &self, collection_view: &UICollectionView, kind: &NSString, index_path: &NSIndexPath, ) -> Retained<UICollectionReusableView>
Available on crate features
UICollectionViewCell and UIResponder and UIScrollView and UIView only.fn collectionView_canMoveItemAtIndexPath( &self, collection_view: &UICollectionView, index_path: &NSIndexPath, ) -> bool
Available on crate features
UIResponder and UIScrollView and UIView only.fn collectionView_moveItemAtIndexPath_toIndexPath( &self, collection_view: &UICollectionView, source_index_path: &NSIndexPath, destination_index_path: &NSIndexPath, )
Available on crate features
UIResponder and UIScrollView and UIView only.Sourcefn indexTitlesForCollectionView(
&self,
collection_view: &UICollectionView,
) -> Option<Retained<NSArray<NSString>>>
Available on crate features UIResponder and UIScrollView and UIView only.
fn indexTitlesForCollectionView( &self, collection_view: &UICollectionView, ) -> Option<Retained<NSArray<NSString>>>
UIResponder and UIScrollView and UIView only.Returns a list of index titles to display in the index view (e.g. [“A”, “B”, “C” … “Z”, “#”])
Sourcefn collectionView_indexPathForIndexTitle_atIndex(
&self,
collection_view: &UICollectionView,
title: &NSString,
index: NSInteger,
) -> Retained<NSIndexPath>
Available on crate features UIResponder and UIScrollView and UIView only.
fn collectionView_indexPathForIndexTitle_atIndex( &self, collection_view: &UICollectionView, title: &NSString, index: NSInteger, ) -> Retained<NSIndexPath>
UIResponder and UIScrollView and UIView only.Returns the index path that corresponds to the given title / index. (e.g. “B”,1) Return an index path with a single index to indicate an entire section, instead of a specific item.