pub unsafe trait UIColorPickerViewControllerDelegate: NSObjectProtocol + MainThreadOnly {
// Provided methods
fn colorPickerViewControllerDidSelectColor(
&self,
view_controller: &UIColorPickerViewController,
)
where Self: Sized + Message { ... }
fn colorPickerViewController_didSelectColor_continuously(
&self,
view_controller: &UIColorPickerViewController,
color: &UIColor,
continuously: bool,
)
where Self: Sized + Message { ... }
fn colorPickerViewControllerDidFinish(
&self,
view_controller: &UIColorPickerViewController,
)
where Self: Sized + Message { ... }
}Available on crate feature
UIColorPickerViewController only.Expand description
Provided Methods
Sourcefn colorPickerViewControllerDidSelectColor(
&self,
view_controller: &UIColorPickerViewController,
)
👎DeprecatedAvailable on crate features UIResponder and UIViewController only.
fn colorPickerViewControllerDidSelectColor( &self, view_controller: &UIColorPickerViewController, )
UIResponder and UIViewController only.Called when the selectedColor changes.
Sourcefn colorPickerViewController_didSelectColor_continuously(
&self,
view_controller: &UIColorPickerViewController,
color: &UIColor,
continuously: bool,
)
Available on crate features UIColor and UIResponder and UIViewController only.
fn colorPickerViewController_didSelectColor_continuously( &self, view_controller: &UIColorPickerViewController, color: &UIColor, continuously: bool, )
UIColor and UIResponder and UIViewController only.Called when the selected color changes.
Parameter viewController: This color picker.
Parameter color: The new selected color
Parameter continuously: YES, if this update is part of a continuous user interaction (e.g. dragging through the spectrum). It’s recommended
to show these updates in your UI but to not include them in any undo operations.
Sourcefn colorPickerViewControllerDidFinish(
&self,
view_controller: &UIColorPickerViewController,
)
Available on crate features UIResponder and UIViewController only.
fn colorPickerViewControllerDidFinish( &self, view_controller: &UIColorPickerViewController, )
UIResponder and UIViewController only.In presentations (except popovers) the color picker shows a close button. If the close button is tapped,
the view controller is dismissed and colorPickerViewControllerDidFinish: is called. Can be used to
animate alongside the dismissal.