pub unsafe trait UISearchSuggestion: NSObjectProtocol + MainThreadOnly {
// Provided methods
fn localizedSuggestion(&self) -> Option<Retained<NSString>>
where Self: Sized + Message { ... }
fn localizedDescription(&self) -> Option<Retained<NSString>>
where Self: Sized + Message { ... }
fn iconImage(&self) -> Option<Retained<UIImage>>
where Self: Sized + Message { ... }
fn localizedAttributedSuggestion(
&self,
) -> Option<Retained<NSAttributedString>>
where Self: Sized + Message { ... }
fn representedObject(&self) -> Option<Retained<AnyObject>>
where Self: Sized + Message { ... }
unsafe fn setRepresentedObject(
&self,
represented_object: Option<&AnyObject>,
)
where Self: Sized + Message { ... }
}Available on crate feature
UISearchSuggestion only.Expand description
Provided Methods
Sourcefn localizedSuggestion(&self) -> Option<Retained<NSString>>
fn localizedSuggestion(&self) -> Option<Retained<NSString>>
The localized suggestion that will be displayed as the search string
Sourcefn localizedDescription(&self) -> Option<Retained<NSString>>
fn localizedDescription(&self) -> Option<Retained<NSString>>
The localized description used as accessibility string
Sourcefn iconImage(&self) -> Option<Retained<UIImage>>
Available on crate feature UIImage only.
fn iconImage(&self) -> Option<Retained<UIImage>>
UIImage only.Icon that represents this search suggestion item
Sourcefn localizedAttributedSuggestion(&self) -> Option<Retained<NSAttributedString>>
fn localizedAttributedSuggestion(&self) -> Option<Retained<NSAttributedString>>
If non-null, will be displayed as the search string instead of localizedSuggestion
Sourcefn representedObject(&self) -> Option<Retained<AnyObject>>
fn representedObject(&self) -> Option<Retained<AnyObject>>
User information
Sourceunsafe fn setRepresentedObject(&self, represented_object: Option<&AnyObject>)
unsafe fn setRepresentedObject(&self, represented_object: Option<&AnyObject>)